/*!
 * Copyright (c) 2025 Vertex Software LLC. All rights reserved.
 */
'use strict';

const bundle_esm = require('./bundle.esm-9f2927ac.js');
const wrappers_pb = require('./wrappers_pb-f76eff58.js');

function requestUnary(caller) {
  return new Promise((resolve, reject) => {
    caller((err, res) => {
      if (err != null) {
        reject(err);
      }
      else if (res != null) {
        resolve(res);
      }
      else {
        reject(new Error('Invalid gRPC response. Error and result are empty.'));
      }
    });
  });
}
function requestPaged(fetch, next) {
  return bundle_esm.__asyncGenerator(this, arguments, function* requestPaged_1() {
    let cursor = undefined;
    do {
      const res = yield bundle_esm.__await(requestUnary(fetch(cursor)));
      yield yield bundle_esm.__await(res);
      cursor = next(res);
    } while (cursor != null);
  });
}
async function createMetadata(jwtProvider, deviceId) {
  const jwt = await jwtProvider();
  const meta = new wrappers_pb.grpcWebClient_umd.grpc.Metadata({
    'jwt-context': JSON.stringify({
      jwt,
      metadata: { 'x-device-id': deviceId || '' },
    }),
  });
  return meta;
}

exports.createMetadata = createMetadata;
exports.requestPaged = requestPaged;
exports.requestUnary = requestUnary;

//# sourceMappingURL=grpc-f1cd4ae7.js.map