/*!
 * Copyright (c) 2025 Vertex Software LLC. All rights reserved.
 */
'use strict';

const browser_esm = require('./browser.esm-91aa64b8.js');
const streamAttributes = require('./streamAttributes-8c3c3d8a.js');

const mapPlanePair = browser_esm.mapper.defineMapper(browser_esm.mapper.read(browser_esm.mapper.mapRequiredProp('start', streamAttributes.fromPbPlane), browser_esm.mapper.mapRequiredProp('end', streamAttributes.fromPbPlane)), ([start, end]) => ({ start, end }));
const mapPlanarDistance = browser_esm.mapper.defineMapper(browser_esm.mapper.read(browser_esm.mapper.getProp('distance'), browser_esm.mapper.mapRequiredProp('planes', browser_esm.mapper.compose(mapPlanePair, browser_esm.mapper.requiredProp('start'))), browser_esm.mapper.mapRequiredProp('planes', browser_esm.mapper.compose(mapPlanePair, browser_esm.mapper.requiredProp('end')))), ([distance, plane1, plane2]) => ({
  type: 'planar-distance',
  distance,
  plane1,
  plane2,
}));
const mapPlanarAngle = browser_esm.mapper.defineMapper(browser_esm.mapper.read(browser_esm.mapper.getProp('angleInRadians'), browser_esm.mapper.mapRequiredProp('planes', browser_esm.mapper.compose(mapPlanePair, browser_esm.mapper.requiredProp('start'))), browser_esm.mapper.mapRequiredProp('planes', browser_esm.mapper.compose(mapPlanePair, browser_esm.mapper.requiredProp('end')))), ([angle, plane1, plane2]) => ({
  type: 'planar-angle',
  angle,
  plane1,
  plane2,
}));
const mapMinimumDistance = browser_esm.mapper.defineMapper(browser_esm.mapper.read(browser_esm.mapper.getProp('distance'), browser_esm.mapper.mapRequiredProp('closestPoint1', streamAttributes.fromPbVector3f), browser_esm.mapper.mapRequiredProp('closestPoint2', streamAttributes.fromPbVector3f)), ([distance, point1, point2]) => ({
  type: 'minimum-distance',
  distance,
  point1,
  point2,
}));
const mapSurfaceArea = browser_esm.mapper.defineMapper(browser_esm.mapper.read(browser_esm.mapper.getProp('area')), ([area]) => ({
  type: 'surface-area',
  area,
}));
const mapPlanarDistanceFromResult = browser_esm.mapper.mapProp('planarDistance', browser_esm.mapper.ifDefined(mapPlanarDistance));
const mapPlanarAngleFromResult = browser_esm.mapper.mapProp('planarAngle', browser_esm.mapper.ifDefined(mapPlanarAngle));
const mapMinimumDistanceFromResult = browser_esm.mapper.mapProp('minimumDistance', browser_esm.mapper.ifDefined(mapMinimumDistance));
const mapSurfaceAreaFromResult = browser_esm.mapper.mapProp('totalSurfaceArea', browser_esm.mapper.ifDefined(mapSurfaceArea));
const mapMeasurementResult = browser_esm.mapper.compose(browser_esm.mapper.pickFirst(mapPlanarDistanceFromResult, mapPlanarAngleFromResult, mapMinimumDistanceFromResult, mapSurfaceAreaFromResult), browser_esm.mapper.required('Result field'));
const mapMeasureResponse = browser_esm.mapper.defineMapper(browser_esm.mapper.read(browser_esm.mapper.mapRequiredProp('outcome', browser_esm.mapper.mapRequiredProp('resultsList', browser_esm.mapper.mapArray(mapMeasurementResult))), browser_esm.mapper.mapRequiredProp('outcome', browser_esm.mapper.getProp('isApproximate'))), ([results, isApproximate]) => ({ results, isApproximate }));
const mapMeasureResponseOrThrow = browser_esm.mapper.ifInvalidThrow(mapMeasureResponse);

exports.mapMeasureResponseOrThrow = mapMeasureResponseOrThrow;

//# sourceMappingURL=mapper-98c59ac6.js.map