/*!
 * Copyright (c) 2025 Vertex Software LLC. All rights reserved.
 */
'use strict';

const bundle_esm = require('./bundle.esm-9f2927ac.js');
const browser_esm = require('./browser.esm-91aa64b8.js');

class MeasurementOverlayManager {
  constructor() {
    this.overlays = new Map();
    this.overlaysChanged = new browser_esm.EventDispatcher();
  }
  addLineFromResult(result) {
    return this.addLine(result.point1, result.point2);
  }
  addLine(start, end) {
    const id = browser_esm.uuid.create();
    const overlay = {
      type: 'line',
      id: id,
      start,
      end,
      dispose: () => this.remove(id),
    };
    this.addOverlay(overlay);
    return overlay;
  }
  addDistanceVectorFromResult(result) {
    return this.addDistanceVector(result.point1, result.point2);
  }
  addDistanceVector(start, end) {
    const id = browser_esm.uuid.create();
    const v = bundle_esm.vector3.subtract(start, end);
    const ye = bundle_esm.vector3.add(start, bundle_esm.vector3.create(0, -v.y, 0));
    const y = { start: start, end: ye };
    const ze = bundle_esm.vector3.add(ye, bundle_esm.vector3.create(0, 0, -v.z));
    const z = { start: ye, end: ze };
    const xe = bundle_esm.vector3.add(ze, bundle_esm.vector3.create(-v.x, 0, 0));
    const x = { start: ze, end: xe };
    const overlay = {
      type: 'distance-vector',
      id,
      x,
      y,
      z,
      dispose: () => this.remove(id),
    };
    this.addOverlay(overlay);
    return overlay;
  }
  addOverlay(overlay) {
    if (!this.overlays.has(overlay.id)) {
      this.overlays.set(overlay.id, overlay);
      this.overlaysChanged.emit(this.getOverlays());
    }
  }
  getOverlays() {
    return Array.from(this.overlays.values());
  }
  remove(id) {
    if (this.overlays.has(id)) {
      this.overlays.delete(id);
      this.overlaysChanged.emit(this.getOverlays());
      return true;
    }
    else {
      return false;
    }
  }
  onOverlaysChanged(listener) {
    return this.overlaysChanged.on(listener);
  }
}

exports.MeasurementOverlayManager = MeasurementOverlayManager;

//# sourceMappingURL=overlays-8906fa5e.js.map