/*!
 * Copyright (c) 2025 Vertex Software LLC. All rights reserved.
 */
'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-4ebe6acf.js');
const index$1 = require('./index-cafdf699.js');
require('./_commonjsHelpers-6d73bb9b.js');

const sceneTreeTableResizeDividerCss = ":host{pointer-events:auto;display:flex;align-items:center;box-sizing:border-box;cursor:col-resize}.divider{width:1px;height:100%;background-color:var(--neutral-300);cursor:col-resize}.divider.highlighted{background-color:var(--blue-600)}";

const SceneTreeTableResizeDivider = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.hovering = false;
    this.dragging = false;
    this.handlePointerDown = () => {
      this.dragging = true;
      window.addEventListener('pointerup', this.handlePointerUp);
    };
    this.handlePointerUp = () => {
      this.dragging = false;
      window.removeEventListener('pointerup', this.handlePointerUp);
    };
    this.handleCellPointerEnter = () => {
      this.hovering = true;
    };
    this.handleCellPointerLeave = () => {
      this.hovering = false;
    };
  }
  render() {
    const isHighlighted = !!this.hovering || !!this.dragging;
    return (index.h(index.Host, { onPointerDown: this.handlePointerDown, onPointerEnter: this.handleCellPointerEnter, onPointerLeave: this.handleCellPointerLeave, style: {
        height: isHighlighted ? '100%' : 'var(--header-height)',
        padding: isHighlighted
          ? '0 calc(var(--scene-tree-table-column-gap) / 2)'
          : 'calc(var(--header-height) / 8) calc(var(--scene-tree-table-column-gap) / 2)',
      } }, index.h("slot", { name: "divider" }, index.h("div", { class: index$1.classnames('divider', {
        highlighted: isHighlighted,
      }) }))));
  }
};
SceneTreeTableResizeDivider.style = sceneTreeTableResizeDividerCss;

exports.vertex_scene_tree_table_resize_divider = SceneTreeTableResizeDivider;

//# sourceMappingURL=vertex-scene-tree-table-resize-divider.cjs.entry.js.map