/*!
 * Copyright (c) 2025 Vertex Software LLC. All rights reserved.
 */
'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-4ebe6acf.js');
const bundle_esm = require('./bundle.esm-9f2927ac.js');
require('./scene_view_api_pb-3310ca49.js');
require('./wrappers_pb-f76eff58.js');
require('./mapper-98c59ac6.js');
require('./streamAttributes-8c3c3d8a.js');
const overlays = require('./overlays-8906fa5e.js');
const utils = require('./utils-328f5502.js');
require('./_commonjsHelpers-6d73bb9b.js');
require('./browser.esm-91aa64b8.js');
require('./bundle.esm-a19223be.js');
require('./entities-ed091fe1.js');

const viewerMeasurementLineCss = ":host{display:block;--viewer-measurement-line-stroke:var(--white);--viewer-measurement-line-stroke-opacity:0.75;--viewer-measurement-line-stroke-width:1.25px;--viewer-measurement-line-fill:var(--neutral-900);--viewer-measurement-line-fill-width:2px;--viewer-measurement-line-start-cap-visibility:initial;--viewer-measurement-line-end-cap-visibility:initial}svg{width:100%;height:100%}.line-stroke{stroke-width:calc(\n    var(--viewer-measurement-line-fill-width) +\n      var(--viewer-measurement-line-stroke-width)\n  );stroke:var(--viewer-measurement-line-stroke);opacity:var(--viewer-measurement-line-stroke-opacity)}.line-fill{stroke-width:var(--viewer-measurement-line-fill-width);stroke:var(--viewer-measurement-line-fill)}.start-cap{visibility:var(--viewer-measurement-line-start-cap-visibility)}.end-cap{visibility:var(--viewer-measurement-line-end-cap-visibility)}";

const ViewerMeasurementLine = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    /**
     * A point that specifies the starting point of the line.
     */
    this.start = bundle_esm.point.create();
    /**
     * A point that specifies the ending point of the line.
     */
    this.end = bundle_esm.point.create();
    /**
     * A length of the line cap. The line cap is a line at each end of a line.
     */
    this.capLength = 0;
    /**
     * The type of [SVG pointer
     * events](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/pointer-events)
     * that the line should respond to.
     */
    this.pointerEvents = 'none';
  }
  /**
   * @ignore
   */
  render() {
    const angle = bundle_esm.angle.fromPoints(this.start, this.end);
    const lineFillEndCaps = getEndCapPoints(this.start, this.end, angle, this.capLength);
    const lineStrokeEndCaps = getEndCapPoints(this.start, this.end, angle, this.capLength + 1);
    return (index.h("svg", null, index.h("g", { class: "line-stroke", "pointer-events": this.pointerEvents }, index.h("line", { class: "line", x1: this.start.x, y1: this.start.y, x2: this.end.x, y2: this.end.y }), index.h("line", { class: "start-cap", x1: lineStrokeEndCaps.startEndCap.start.x, y1: lineStrokeEndCaps.startEndCap.start.y, x2: lineStrokeEndCaps.startEndCap.end.x, y2: lineStrokeEndCaps.startEndCap.end.y }), index.h("line", { class: "end-cap", x1: lineStrokeEndCaps.endEndCap.start.x, y1: lineStrokeEndCaps.endEndCap.start.y, x2: lineStrokeEndCaps.endEndCap.end.x, y2: lineStrokeEndCaps.endEndCap.end.y })), index.h("g", { class: "line-fill", "pointer-events": this.pointerEvents }, index.h("line", { class: "line", x1: this.start.x, y1: this.start.y, x2: this.end.x, y2: this.end.y }), index.h("line", { class: "start-cap", x1: lineFillEndCaps.startEndCap.start.x, y1: lineFillEndCaps.startEndCap.start.y, x2: lineFillEndCaps.startEndCap.end.x, y2: lineFillEndCaps.startEndCap.end.y }), index.h("line", { class: "end-cap", x1: lineFillEndCaps.endEndCap.start.x, y1: lineFillEndCaps.endEndCap.start.y, x2: lineFillEndCaps.endEndCap.end.x, y2: lineFillEndCaps.endEndCap.end.y }))));
  }
};
function getEndCapPoints(start, end, angle, length) {
  return {
    startEndCap: getPerpendicularLine(start, angle, length),
    endEndCap: getPerpendicularLine(end, angle, length),
  };
}
function getPerpendicularLine(pt, angle, length) {
  const perpAngle = angle + Math.PI / 2;
  const start = bundle_esm.point.add(pt, bundle_esm.point.polar(length / 2, perpAngle));
  const end = bundle_esm.point.add(pt, bundle_esm.point.polar(length / 2, perpAngle + Math.PI));
  return { start, end };
}
ViewerMeasurementLine.style = viewerMeasurementLineCss;

// eslint-disable-next-line @typescript-eslint/no-unused-vars
const MeasurementOverlayView = ({ overlay, viewport, camera }) => {
  if (overlay.type === 'line') {
    return (index.h(LineOverlayView, { overlay: overlay, viewport: viewport, camera: camera }));
  }
  else {
    return (index.h(DistanceVectorOverlayView, { overlay: overlay, viewport: viewport, camera: camera }));
  }
};
const LineOverlayView = ({ overlay, camera, viewport }) => {
  const { start, end } = utils.translateWorldLineToViewport(overlay, {
    camera,
    viewport,
  });
  return (index.h("vertex-viewer-measurement-line", { class: "measurement-line", start: start, end: end }));
};
const DistanceVectorOverlayView = ({ overlay: { x, y, z }, camera, viewport }) => {
  const params = { camera, viewport };
  const { start: xs, end: xe } = utils.translateWorldLineToViewport(x, params);
  const { start: ys, end: ye } = utils.translateWorldLineToViewport(y, params);
  const { start: zs, end: ze } = utils.translateWorldLineToViewport(z, params);
  return (index.h(index.Fragment, null,
    index.h("vertex-viewer-measurement-line", { class: "measurement-line distance-vector-x", start: xs, end: xe }),
    index.h("vertex-viewer-measurement-line", { class: "measurement-line distance-vector-y", start: ys, end: ye }),
    index.h("vertex-viewer-measurement-line", { class: "measurement-line distance-vector-z", start: zs, end: ze })));
};

const viewerMeasurementOverlaysCss = ":host{display:block;position:absolute;top:0;bottom:0;left:0;right:0;pointer-events:none;--viewer-measurement-overlays-x-axis-color:var(--x-axis-color);--viewer-measurement-overlays-y-axis-color:var(--y-axis-color);--viewer-measurement-overlays-z-axis-color:var(--z-axis-color)}.measurement-line{position:absolute;width:100%;height:100%}.measurement-line.distance-vector-x{--viewer-measurement-line-fill:var(\n    --viewer-measurement-overlays-x-axis-color\n  )}.measurement-line.distance-vector-y{--viewer-measurement-line-fill:var(\n    --viewer-measurement-overlays-y-axis-color\n  )}.measurement-line.distance-vector-z{--viewer-measurement-line-fill:var(\n    --viewer-measurement-overlays-z-axis-color\n  )}";

const ViewerMeasurementOverlays = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    /**
     * The model that contains the overlays to present.
     */
    this.measurementOverlays = new overlays.MeasurementOverlayManager();
    this.overlays = [];
    this.updateCamera = () => {
      var _a, _b;
      this.camera = (_b = (_a = this.viewer) === null || _a === void 0 ? void 0 : _a.frame) === null || _b === void 0 ? void 0 : _b.scene.camera;
    };
  }
  /**
   * @ignore
   */
  handleMeasurementOverlaysChanged() {
    this.removeModelListeners();
    this.addModelListeners();
    this.updateOverlays();
  }
  /**
   * @ignore
   */
  handleViewerChanged(newViewer, oldViewer) {
    this.removeViewerListeners(oldViewer);
    this.addViewerListeners();
    this.updateCamera();
  }
  /**
   * @ignore
   */
  componentWillLoad() {
    this.addModelListeners();
    this.addViewerListeners();
    this.updateOverlays();
    this.updateCamera();
  }
  addModelListeners() {
    this.onOverlaysChangedListener = this.measurementOverlays.onOverlaysChanged(() => this.updateOverlays());
  }
  removeModelListeners() {
    var _a;
    (_a = this.onOverlaysChangedListener) === null || _a === void 0 ? void 0 : _a.dispose();
    this.onOverlaysChangedListener = undefined;
  }
  addViewerListeners() {
    var _a;
    (_a = this.viewer) === null || _a === void 0 ? void 0 : _a.addEventListener('frameReceived', this.updateCamera);
  }
  removeViewerListeners(viewer) {
    viewer === null || viewer === void 0 ? void 0 : viewer.removeEventListener('frameReceived', this.updateCamera);
  }
  updateOverlays() {
    this.overlays = this.measurementOverlays.getOverlays();
  }
  /**
   * @ignore
   */
  render() {
    return (index.h(index.Host, null, this.overlays.map((overlay) => {
      if (this.camera != null && this.viewer != null) {
        return (index.h(MeasurementOverlayView, { overlay: overlay, viewport: this.viewer.viewport, camera: this.camera }));
      }
    })));
  }
  static get watchers() { return {
    "measurementOverlays": ["handleMeasurementOverlaysChanged"],
    "viewer": ["handleViewerChanged"]
  }; }
};
ViewerMeasurementOverlays.style = viewerMeasurementOverlaysCss;

exports.vertex_viewer_measurement_line = ViewerMeasurementLine;
exports.vertex_viewer_measurement_overlays = ViewerMeasurementOverlays;

//# sourceMappingURL=vertex-viewer-measurement-line_2.cjs.entry.js.map