/*!
 * Copyright (c) 2025 Vertex Software LLC. All rights reserved.
 */
'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-4ebe6acf.js');
const bundle_esm = require('./bundle.esm-9f2927ac.js');
require('./controller-6a70e6f9.js');
require('./cursors-1f5d9d93.js');
require('./scene_view_api_pb-3310ca49.js');
require('./wrappers_pb-f76eff58.js');
require('./mapper-98c59ac6.js');
require('./streamAttributes-8c3c3d8a.js');
require('./mapper-f1521d42.js');
require('./entities-ed091fe1.js');
const viewport = require('./viewport-b2283e4b.js');
const model = require('./model-14c03301.js');
const index$1 = require('./index-cafdf699.js');
require('./errors-959312c1.js');
require('./_commonjsHelpers-6d73bb9b.js');
require('./browser.esm-91aa64b8.js');
require('./row-474ad32c.js');
require('./bundle.esm-a19223be.js');

// eslint-disable-next-line @typescript-eslint/no-unused-vars
const PinRenderer = ({ pin, selected, occluded, detached, }) => {
  const { primaryColor } = model.getPinColors(pin);
  return (index.h(index.Fragment, null,
    model.isTextPin(pin) && (index.h("div", { id: "pin-anchor", class: index$1.classnames('pin-anchor', {
        selected: selected,
        'pin-occluded': occluded,
        'pin-detached': detached,
      }), style: {
        background: primaryColor,
      } })),
    model.isIconPin(pin) && (index.h("vertex-viewer-icon", { name: "pin-fill", size: "lg", class: index$1.classnames('pin', {
        'pin-selected': selected,
        'pin-occluded': occluded,
        'pin-detached': detached,
      }), style: {
        color: primaryColor,
      } }))));
};

function getClosestCenterToPoint(boxPoint, pointToMeasure, dimensions) {
  const topPoint = {
    x: boxPoint.x + dimensions.width / 2,
    y: boxPoint.y,
  };
  const bottomPoint = {
    x: boxPoint.x + dimensions.width / 2,
    y: boxPoint.y + dimensions.height,
  };
  const rightPoint = {
    x: boxPoint.x + dimensions.width,
    y: boxPoint.y + dimensions.height / 2,
  };
  const leftPoint = {
    x: boxPoint.x,
    y: boxPoint.y + dimensions.height / 2,
  };
  const candidates = [topPoint, bottomPoint, leftPoint, rightPoint];
  const distances = candidates.map((candidate) => bundle_esm.point.distance(candidate, pointToMeasure));
  const candidateIndex = distances.indexOf(Math.min(...distances));
  return candidates[candidateIndex];
}

const viewerPinGroupCss = ":host{--viewer-annotations-pin-primary-color:var(--blue-700);--viewer-annotations-pin-accent-color:var(--blue-200);--viewer-annotations-pin-dot-color:var(--viewer-annotations-pin-primary-color);--viewer-annotations-pin-color:var(--viewer-annotations-pin-primary-color);--viewer-annotations-pin-font-size:0.75rem;--viewer-annotations-pin-selected-stroke:var(--white);--viewer-annotations-pin-selected-border:2px solid var(--white);--viewer-annotations-pin-label-border:2px solid var(--black);--viewer-annotations-pin-selected-stroke:var(--white);font-size:var(--viewer-annotations-pin-font-size);position:absolute;top:0;bottom:0;left:0;right:0;overflow:hidden;pointer-events:none}.pin-anchor{position:absolute;border-radius:50%;transform:translate(-50%, -50%);display:block;width:9px;height:9px;box-sizing:border-box;border:var(--viewer-annotations-pin-label-border);background:var(--viewer-annotations-pin-dot-color);pointer-events:auto;cursor:pointer}.selected{width:13px;height:13px;border:var(--viewer-annotations-pin-selected-border)}.pin{color:var(--viewer-annotations-pin-color);cursor:pointer;transition:opacity 0.3s ease-in}.pin-selected{stroke-width:1;stroke:var(--viewer-annotations-pin-selected-stroke)}.pin-occluded{opacity:.3;transition:opacity 0.3s ease-in}.pin-detached{visibility:hidden}";

const ViewerPinGroup = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    /**
     * The local matrix of this element.
     */
    this.matrix = bundle_esm.matrix4.makeIdentity();
    /**
     * Projection view matrix used for computing the position of the pin line
     */
    this.projectionViewMatrix = bundle_esm.matrix4.makeIdentity();
    /**
     * The model that contains the entities and outcomes from performing pin operations
     */
    this.pinModel = new model.PinModel();
    /**
     * Whether the pin is "selected"
     */
    this.selected = false;
    /**
     * @internal
     * Whether the pin is occluded
     */
    this.occluded = false;
    /**
     * @internal
     * Whether the pin is detached
     */
    this.detached = false;
    this.invalidateStateCounter = 0;
    this.invalidateState = () => {
      this.invalidateStateCounter = this.invalidateStateCounter + 1;
    };
  }
  componentDidLoad() {
    var _a;
    this.setLabelObserver();
    if (this.pinController == null) {
      this.pinController = new model.PinController(this.pinModel);
    }
    if (this.selected) {
      (_a = this.labelEl) === null || _a === void 0 ? void 0 : _a.setFocus();
    }
  }
  /**
   * @ignore
   */
  async handleOcclusionStateChanged(event) {
    this.occluded = event.detail;
  }
  /**
   * @ignore
   */
  async handleDetachedStateChanged(event) {
    this.detached = event.detail;
  }
  disconnectedCallback() {
    var _a, _b;
    (_a = this.labelEl) === null || _a === void 0 ? void 0 : _a.removeEventListener('labelChanged', this.invalidateState);
    (_b = this.resizeObserver) === null || _b === void 0 ? void 0 : _b.disconnect();
  }
  render() {
    var _a;
    if (this.pin == null) {
      throw new Error('Unable to draw pin');
    }
    const { pinPoint, labelPoint } = this.computePinPoints(this.pin);
    return (index.h(index.Fragment, null, index.h("vertex-viewer-dom-element", { "data-testid": `drawn-pin-${this.pin.id}`, position: this.pin.worldPosition, onPointerDown: async () => {
        var _a;
        await ((_a = this.labelEl) === null || _a === void 0 ? void 0 : _a.submit());
        this.selectPin();
        this.handleAnchorPointerDown();
      }, detachedOff: false }, index.h(PinRenderer, { pin: this.pin, selected: this.selected, occluded: this.occluded, detached: this.detached })), model.isTextPin(this.pin) && !this.occluded && !this.detached && (index.h(index.Fragment, null, index.h("vertex-viewer-pin-label-line", { id: `pin-label-line-${(_a = this.pin) === null || _a === void 0 ? void 0 : _a.id}`, pinPoint: pinPoint, pin: this.pin, labelPoint: labelPoint, onPointerDown: () => this.selectPin() }), index.h("vertex-viewer-pin-label", { pin: this.pin, ref: (el) => (this.labelEl = el), elementBounds: this.elementBounds, pinController: this.pinController, onPointerDown: () => this.selectPin() })))));
  }
  setLabelObserver() {
    if (this.labelEl != null) {
      this.labelEl.addEventListener('labelChanged', this.invalidateState);
      this.resizeObserver = new ResizeObserver(() => this.invalidateState());
      this.resizeObserver.observe(this.labelEl);
    }
  }
  computePinPoints(pin) {
    if (this.elementBounds != null && this.pin != null) {
      return model.isTextPin(this.pin) && this.pin.label.point != null
        ? this.computeTextPinPoints(this.pin, this.elementBounds)
        : this.computeDefaultPinPoints(this.pin, this.elementBounds);
    }
    return { pinPoint: pin.worldPosition };
  }
  computeDefaultPinPoints(pin, elementBounds) {
    return {
      pinPoint: this.getFromWorldPosition(pin.worldPosition, this.projectionViewMatrix, elementBounds),
    };
  }
  computeTextPinPoints(pin, elementBounds) {
    var _a, _b, _c, _d;
    const { pinPoint } = this.computeDefaultPinPoints(pin, elementBounds);
    const screenPosition = model.translatePointToScreen(pin.label.point, elementBounds);
    const labelWidth = ((_b = (_a = this.labelEl) === null || _a === void 0 ? void 0 : _a.firstElementChild) === null || _b === void 0 ? void 0 : _b.clientWidth) || 0;
    const labelHeight = ((_d = (_c = this.labelEl) === null || _c === void 0 ? void 0 : _c.firstElementChild) === null || _d === void 0 ? void 0 : _d.clientHeight) || 0;
    return {
      pinPoint,
      labelPoint: getClosestCenterToPoint(screenPosition, pinPoint, {
        width: labelWidth,
        height: labelHeight,
      }),
    };
  }
  handleAnchorPointerDown() {
    var _a, _b;
    if (this.elementBounds != null &&
      ((_a = this.pinController) === null || _a === void 0 ? void 0 : _a.getToolMode()) === 'edit' &&
      this.pin != null) {
      (_b = this.pinController) === null || _b === void 0 ? void 0 : _b.setDraggable({ id: this.pin.id });
    }
  }
  selectPin() {
    var _a, _b;
    (_a = this.pinController) === null || _a === void 0 ? void 0 : _a.setSelectedPinId((_b = this.pin) === null || _b === void 0 ? void 0 : _b.id);
  }
  getFromWorldPosition(pt, projectionViewMatrix, dimensions) {
    const ndcPt = bundle_esm.vector3.transformMatrix(pt, projectionViewMatrix);
    return viewport.Viewport.fromDimensions(dimensions).transformVectorToViewport(ndcPt);
  }
};
ViewerPinGroup.style = viewerPinGroupCss;

exports.vertex_viewer_pin_group = ViewerPinGroup;

//# sourceMappingURL=vertex-viewer-pin-group.cjs.entry.js.map