/*!
 * Copyright (c) 2025 Vertex Software LLC. All rights reserved.
 */
'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-4ebe6acf.js');
const bundle_esm = require('./bundle.esm-9f2927ac.js');
const stencil = require('./stencil-1be2254b.js');
const streamAttributes = require('./streamAttributes-8c3c3d8a.js');
require('./entities-ed091fe1.js');
const index$1 = require('./index-cafdf699.js');
require('./bundle.esm-a19223be.js');
require('./browser.esm-91aa64b8.js');
require('./_commonjsHelpers-6d73bb9b.js');

// eslint-disable-next-line @typescript-eslint/no-unused-vars
const viewCubeSides = {
  front: {
    direction: bundle_esm.vector3.back(),
    quaternion: bundle_esm.quaternion.create(),
  },
  back: {
    direction: bundle_esm.vector3.forward(),
    quaternion: bundle_esm.quaternion.fromAxisAngle(bundle_esm.vector3.up(), Math.PI),
  },
  left: {
    direction: bundle_esm.vector3.left(),
    quaternion: bundle_esm.quaternion.fromAxisAngle(bundle_esm.vector3.down(), Math.PI / 2),
  },
  right: {
    direction: bundle_esm.vector3.right(),
    quaternion: bundle_esm.quaternion.fromAxisAngle(bundle_esm.vector3.up(), Math.PI / 2),
  },
  top: {
    direction: bundle_esm.vector3.up(),
    quaternion: bundle_esm.quaternion.fromAxisAngle(bundle_esm.vector3.right(), -Math.PI / 2),
  },
  bottom: {
    direction: bundle_esm.vector3.down(),
    quaternion: bundle_esm.quaternion.fromAxisAngle(bundle_esm.vector3.left(), -Math.PI / 2),
  },
};
const TriadAxis = ({ label, length, rotationAxis, }) => {
  const axisStyles = { width: `${length + 5}px` };
  const quaternion = bundle_esm.quaternion.fromAxisAngle(rotationAxis, Math.PI / 2);
  const labelPos = bundle_esm.vector3.scale(length + 15, bundle_esm.vector3.right());
  return (index.h(index.Fragment, null,
    index.h("vertex-viewer-dom-group", { quaternion: quaternion },
      index.h("vertex-viewer-dom-element", { style: axisStyles, billboardOff: true, interactionsOff: true },
        index.h("div", { class: `triad-axis triad-axis-${label.toLowerCase()}` })),
      index.h("vertex-viewer-dom-element", { rotation: bundle_esm.euler.create({ x: Math.PI / 2, y: 0, z: 0 }), style: axisStyles, billboardOff: true, interactionsOff: true },
        index.h("div", { class: `triad-axis triad-axis-${label.toLowerCase()}` })),
      index.h("vertex-viewer-dom-element", { position: labelPos, interactionsOff: true },
        index.h("div", { class: `triad-label triad-label-${label.toLowerCase()}` }, label)))));
};
const ViewCubeSide = ({ label, length, side, disabled, onPointerDown, }) => {
  const { direction, quaternion } = viewCubeSides[side];
  const position = bundle_esm.vector3.scale(length / 2 - 0.1, direction);
  return (index.h("vertex-viewer-dom-element", { class: index$1.classnames('cube-side', { disabled }), position: position, quaternion: quaternion, style: { width: `${length}px`, height: `${length}px` }, onPointerDown: onPointerDown, billboardOff: true },
    index.h("div", { class: `cube-side-face cube-side-face-${label.toLowerCase()}` }, label)));
};
const ViewCubeCorner = ({ length, face1Side, face1Corner, face2Side, face2Corner, face3Side, face3Corner, disabled, onPointerDown, }) => {
  const { direction: dir1, quaternion: rot1 } = viewCubeSides[face1Side];
  const { direction: dir2, quaternion: rot2 } = viewCubeSides[face2Side];
  const { direction: dir3, quaternion: rot3 } = viewCubeSides[face3Side];
  const position1 = bundle_esm.vector3.scale(length / 2, dir1);
  const position2 = bundle_esm.vector3.scale(length / 2, dir2);
  const position3 = bundle_esm.vector3.scale(length / 2, dir3);
  const styles = { width: `${length}px`, height: `${length}px` };
  return (index.h("vertex-viewer-dom-group", { class: index$1.classnames('cube-corner', { disabled }), onPointerDown: onPointerDown },
    index.h("vertex-viewer-dom-element", { position: position1, quaternion: rot1, style: styles, billboardOff: true },
      index.h("div", { class: `cube-corner-face ${face1Corner}` })),
    index.h("vertex-viewer-dom-element", { position: position2, quaternion: rot2, style: styles, billboardOff: true },
      index.h("div", { class: `cube-corner-face ${face2Corner}` })),
    index.h("vertex-viewer-dom-element", { position: position3, quaternion: rot3, style: styles, billboardOff: true },
      index.h("div", { class: `cube-corner-face ${face3Corner}` }))));
};
const ViewCubeEdge = ({ length, face1Side, face2Side, face1Edge, face2Edge, disabled, onPointerDown, }) => {
  const { direction: dir1, quaternion: rot1 } = viewCubeSides[face1Side];
  const { direction: dir2, quaternion: rot2 } = viewCubeSides[face2Side];
  const position1 = bundle_esm.vector3.scale(length / 2, dir1);
  const position2 = bundle_esm.vector3.scale(length / 2, dir2);
  const styles = { width: `${length}px`, height: `${length}px` };
  return (index.h("vertex-viewer-dom-group", { class: index$1.classnames('cube-edge', { disabled }), onPointerDown: onPointerDown },
    index.h("vertex-viewer-dom-element", { position: position1, quaternion: rot1, style: styles, billboardOff: true },
      index.h("div", { class: `cube-edge-face ${face1Edge}` })),
    index.h("vertex-viewer-dom-element", { position: position2, quaternion: rot2, style: styles, billboardOff: true },
      index.h("div", { class: `cube-edge-face ${face2Edge}` }))));
};
const ViewCubeShadow = ({ length, }) => {
  const { direction, quaternion } = viewCubeSides.top;
  const position = bundle_esm.vector3.scale(-length / 2, direction);
  return (index.h("vertex-viewer-dom-element", { class: "cube-shadow", position: position, quaternion: quaternion, style: { width: `${length}px`, height: `${length}px` }, billboardOff: true, interactionsOff: true },
    index.h("div", { class: "cube-shadow-face" })));
};

const viewerViewCubeCss = ":host{--viewer-view-cube-side-background:var(--white);--viewer-view-cube-side-background-hover:var(--blue-500);--viewer-view-cube-side-background-hover-opacity:0.25;--viewer-view-cube-side-border:1.5px solid var(--neutral-500);--viewer-view-cube-edge-length:12px;--viewer-view-cube-opacity:0.8;--viewer-view-cube-triad-x-axis-color:var(--x-axis-color);--viewer-view-cube-triad-y-axis-color:var(--y-axis-color);--viewer-view-cube-triad-z-axis-color:var(--z-axis-color);color:var(--neutral-700);width:80px;height:80px;margin:20px;position:relative;display:flex;align-items:center;justify-content:center;user-select:none}.renderer{position:unset;width:100%;height:100%;overflow:visible !important}.reference-point{width:5px;height:5px;border-radius:50%;background-color:black}.triad{pointer-events:none}.triad-axis{width:100%;height:1.5px;outline:1px solid transparent;transform:translateX(50%)}.triad-axis-x{background-color:#ea3324}.triad-axis-y{background-color:#4faf32}.triad-axis-z{background-color:#0000ff}.triad-label{font-family:Arial, Helvetica, sans-serif;font-size:0.6875rem}.triad-label-x{color:var(--viewer-view-cube-triad-x-axis-color)}.triad-label-y{color:var(--viewer-view-cube-triad-y-axis-color)}.triad-label-z{color:var(--viewer-view-cube-triad-z-axis-color)}.cube{pointer-events:initial}.cube:hover .cube-side-face{opacity:1}.cube-side{backface-visibility:hidden;-webkit-backface-visibility:hidden}.cube-side-face{box-sizing:border-box;font-size:0.875rem;text-transform:uppercase;width:100%;height:100%;background-color:var(--viewer-view-cube-side-background);border:var(--viewer-view-cube-side-border);display:flex;align-items:center;justify-content:center;outline:1px solid transparent;opacity:var(--viewer-view-cube-opacity);transition:opacity 0.2s ease-in-out}.cube-side-face::before{content:'';position:absolute;left:calc(var(--viewer-view-cube-edge-length) - 4px);right:calc(var(--viewer-view-cube-edge-length) - 4px);top:calc(var(--viewer-view-cube-edge-length) - 4px);bottom:calc(var(--viewer-view-cube-edge-length) - 4px)}.cube-corner,.cube-edge{position:relative}.cube-corner-face,.cube-edge-face{position:absolute;backface-visibility:hidden;-webkit-backface-visibility:hidden}.cube-edge-face.top{top:0;left:var(--viewer-view-cube-edge-length);right:var(--viewer-view-cube-edge-length);height:var(--viewer-view-cube-edge-length)}.cube-edge-face.bottom{bottom:0;left:var(--viewer-view-cube-edge-length);right:var(--viewer-view-cube-edge-length);height:var(--viewer-view-cube-edge-length)}.cube-edge-face.left{left:0;top:var(--viewer-view-cube-edge-length);bottom:var(--viewer-view-cube-edge-length);width:var(--viewer-view-cube-edge-length)}.cube-edge-face.right{right:0;top:var(--viewer-view-cube-edge-length);bottom:var(--viewer-view-cube-edge-length);width:var(--viewer-view-cube-edge-length)}.cube-corner-face{width:var(--viewer-view-cube-edge-length);height:var(--viewer-view-cube-edge-length)}.cube-corner-face.top-left{top:0;left:0}.cube-corner-face.top-right{top:0;right:0}.cube-corner-face.bottom-right{bottom:0;right:0}.cube-corner-face.bottom-left{bottom:0;left:0}.cube-shadow{backface-visibility:hidden;-webkit-backface-visibility:hidden}.cube-shadow-face{position:absolute;left:4px;right:4px;top:4px;bottom:4px;background-color:black;opacity:0.12;filter:blur(4px)}.cube-side-face,.cube-corner-face,.cube-edge-face{pointer-events:initial}.cube-corner .cube-corner-face,.cube-edge .cube-edge-face,.cube-side .cube-side-face::before{background:var(--viewer-view-cube-side-background-hover);opacity:0}.cube-corner:hover .cube-corner-face,.cube-edge:hover .cube-edge-face,.cube-side:hover .cube-side-face::before{opacity:var(--viewer-view-cube-side-background-hover-opacity)}.cube-corner.disabled,.cube-edge.disabled,.cube-side.disabled{pointer-events:none}";

const ViewerViewCube = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.boxLength = 80;
    this.triadPosition = bundle_esm.vector3.origin();
    /**
     * The label for the side of the cube on the positive x-axis.
     */
    this.xPositiveLabel = 'Right';
    /**
     * The label for the side of the cube on the negative x-axis.
     */
    this.xNegativeLabel = 'Left';
    /**
     * The label for the side of the cube on the positive y-axis.
     */
    this.yPositiveLabel = 'Top';
    /**
     * The label for the side of the cube on the negative y-axis.
     */
    this.yNegativeLabel = 'Bottom';
    /**
     * The label for the side of the cube on the positive z-axis.
     */
    this.zPositiveLabel = 'Front';
    /**
     * The label for the side of the cube on the negative z-axis.
     */
    this.zNegativeLabel = 'Back';
    /**
     * Disables interactions for standard views.
     */
    this.standardViewsOff = false;
    /**
     * Whether to perform a `viewAll` when clicking on the view cube. If this
     * is set to `false`, the current `lookAt` point will be maintained, and the
     * camera's `position` and `up` vectors will be aligned to the standard view.
     * Defaults to `true`.
     *
     * **Note** Setting this value to `false` can result in the camera being placed
     * underneath geometry depending on the current `viewVector` length, resulting
     * in a view that may be unexpected.
     */
    this.viewAll = true;
    /**
     * The duration of the animation, in milliseconds, when a user performs a
     * standard view interaction. Set to 0 to disable animations.
     */
    this.animationDuration = 500;
    /**
     * Disables the display of the triad.
     */
    this.triadOff = false;
    /**
     * @internal
     */
    this.worldOrientation = streamAttributes.Orientation.DEFAULT;
    this.updateMatrices = () => {
      var _a;
      if (((_a = this.viewer) === null || _a === void 0 ? void 0 : _a.frame) != null) {
        const { camera } = this.viewer.frame.scene;
        const halfLength = this.boxLength / 2;
        this.triadPosition = bundle_esm.vector3.create(-halfLength - 5, -halfLength - 5, -halfLength - 5);
        // Used to scale the camera position so the cube is the same size as the
        // container. This isn't exact, but pretty close.
        const lengthScalar = 3.125;
        const scale = this.boxLength * lengthScalar;
        const fovY = 21.5;
        this.camera = new streamAttributes.FramePerspectiveCamera(bundle_esm.vector3.scale(scale, bundle_esm.vector3.negate(camera.direction)), bundle_esm.vector3.origin(), camera.up, 0.1, 100, 1, fovY);
        this.worldOrientation = this.viewer.frame.scene.worldOrientation;
      }
    };
  }
  handleViewerChanged(newViewer, oldViewer) {
    oldViewer === null || oldViewer === void 0 ? void 0 : oldViewer.removeEventListener('frameDrawn', this.updateMatrices);
    newViewer === null || newViewer === void 0 ? void 0 : newViewer.addEventListener('frameDrawn', this.updateMatrices);
    this.updateMatrices();
  }
  handleStandardView(standardView) {
    if (this.standardViewsOff) {
      return async () => undefined;
    }
    else {
      return async () => {
        if (this.viewer != null) {
          const scene = await this.viewer.scene();
          const animation = this.animationDuration > 0
            ? { animation: { milliseconds: this.animationDuration } }
            : {};
          const worldStandardView = standardView.transformMatrix(this.worldOrientation.matrix);
          // Check to see if any geometry is visible. If not, don't perform viewAll
          const currentBoundingBox = scene.boundingBox();
          if (!this.viewAll) {
            scene
              .camera()
              .standardViewFixedLookAt(worldStandardView)
              .render(animation);
          }
          else if ((currentBoundingBox === null || currentBoundingBox === void 0 ? void 0 : currentBoundingBox.max) != null &&
            bundle_esm.vector3.isEqual(currentBoundingBox.max, bundle_esm.vector3.origin()) &&
            bundle_esm.vector3.isEqual(currentBoundingBox.min, bundle_esm.vector3.origin())) {
            scene.camera().standardView(worldStandardView).render(animation);
          }
          else {
            scene
              .camera()
              .standardView(worldStandardView)
              .viewAll()
              .render(animation);
          }
        }
      };
    }
  }
  /**
   * @ignore
   */
  componentWillLoad() {
    this.handleViewerChanged(this.viewer);
  }
  /**
   * @ignore
   */
  componentDidLoad() {
    if (this.rendererEl != null) {
      const observer = new ResizeObserver(() => this.handleRendererResized());
      observer.observe(this.rendererEl);
      this.handleRendererResized();
    }
  }
  handleRendererResized() {
    stencil.readDOM(() => {
      if (this.rendererEl != null) {
        const rect = this.rendererEl.getBoundingClientRect();
        this.boxLength = Math.min(rect.width, rect.height);
      }
    });
  }
  /**
   * @ignore
   */
  render() {
    return (index.h(index.Host, null, index.h("vertex-viewer-dom-renderer", { ref: (ref) => (this.rendererEl = ref), class: "renderer", camera: this.camera }, !this.triadOff && (index.h("vertex-viewer-dom-group", { class: "triad", position: this.triadPosition }, index.h(TriadAxis, { label: "X", length: this.boxLength, rotationAxis: bundle_esm.vector3.origin() }), index.h(TriadAxis, { label: "Y", length: this.boxLength, rotationAxis: bundle_esm.vector3.back() }), index.h(TriadAxis, { label: "Z", length: this.boxLength, rotationAxis: bundle_esm.vector3.down() }))), index.h("vertex-viewer-dom-group", { class: "cube", matrix: this.worldOrientation.matrix }, index.h(ViewCubeShadow, { length: this.boxLength + 10 }), index.h(ViewCubeSide, { label: this.zPositiveLabel, length: this.boxLength, side: "front", onPointerDown: this.handleStandardView(streamAttributes.StandardView.FRONT), disabled: this.standardViewsOff }), index.h(ViewCubeSide, { label: this.zNegativeLabel, length: this.boxLength, side: "back", onPointerDown: this.handleStandardView(streamAttributes.StandardView.BACK), disabled: this.standardViewsOff }), index.h(ViewCubeSide, { label: this.xNegativeLabel, length: this.boxLength, side: "left", onPointerDown: this.handleStandardView(streamAttributes.StandardView.RIGHT), disabled: this.standardViewsOff }), index.h(ViewCubeSide, { label: this.xPositiveLabel, length: this.boxLength, side: "right", onPointerDown: this.handleStandardView(streamAttributes.StandardView.LEFT), disabled: this.standardViewsOff }), index.h(ViewCubeSide, { label: this.yPositiveLabel, length: this.boxLength, side: "top", onPointerDown: this.handleStandardView(streamAttributes.StandardView.TOP), disabled: this.standardViewsOff }), index.h(ViewCubeSide, { label: this.yNegativeLabel, length: this.boxLength, side: "bottom", onPointerDown: this.handleStandardView(streamAttributes.StandardView.BOTTOM), disabled: this.standardViewsOff }), index.h(ViewCubeEdge, { length: this.boxLength, face1Side: "top", face1Edge: "bottom", face2Side: "front", face2Edge: "top", onPointerDown: this.handleStandardView(streamAttributes.StandardView.TOP_FRONT), disabled: this.standardViewsOff }), index.h(ViewCubeEdge, { length: this.boxLength, face1Side: "front", face1Edge: "right", face2Side: "right", face2Edge: "left", onPointerDown: this.handleStandardView(streamAttributes.StandardView.FRONT_LEFT), disabled: this.standardViewsOff }), index.h(ViewCubeEdge, { length: this.boxLength, face1Side: "bottom", face1Edge: "top", face2Side: "front", face2Edge: "bottom", onPointerDown: this.handleStandardView(streamAttributes.StandardView.BOTTOM_FRONT), disabled: this.standardViewsOff }), index.h(ViewCubeEdge, { length: this.boxLength, face1Side: "front", face1Edge: "left", face2Side: "left", face2Edge: "right", onPointerDown: this.handleStandardView(streamAttributes.StandardView.FRONT_RIGHT), disabled: this.standardViewsOff }), index.h(ViewCubeEdge, { length: this.boxLength, face1Side: "top", face1Edge: "right", face2Side: "right", face2Edge: "top", onPointerDown: this.handleStandardView(streamAttributes.StandardView.TOP_LEFT), disabled: this.standardViewsOff }), index.h(ViewCubeEdge, { length: this.boxLength, face1Side: "back", face1Edge: "left", face2Side: "right", face2Edge: "right", onPointerDown: this.handleStandardView(streamAttributes.StandardView.BACK_LEFT), disabled: this.standardViewsOff }), index.h(ViewCubeEdge, { length: this.boxLength, face1Side: "bottom", face1Edge: "right", face2Side: "right", face2Edge: "bottom", onPointerDown: this.handleStandardView(streamAttributes.StandardView.BOTTOM_LEFT), disabled: this.standardViewsOff }), index.h(ViewCubeEdge, { length: this.boxLength, face1Side: "top", face1Edge: "top", face2Side: "back", face2Edge: "top", onPointerDown: this.handleStandardView(streamAttributes.StandardView.TOP_BACK), disabled: this.standardViewsOff }), index.h(ViewCubeEdge, { length: this.boxLength, face1Side: "back", face1Edge: "right", face2Side: "left", face2Edge: "left", onPointerDown: this.handleStandardView(streamAttributes.StandardView.BACK_RIGHT), disabled: this.standardViewsOff }), index.h(ViewCubeEdge, { length: this.boxLength, face1Side: "bottom", face1Edge: "bottom", face2Side: "back", face2Edge: "bottom", onPointerDown: this.handleStandardView(streamAttributes.StandardView.BOTTOM_BACK), disabled: this.standardViewsOff }), index.h(ViewCubeEdge, { length: this.boxLength, face1Side: "top", face1Edge: "left", face2Side: "left", face2Edge: "top", onPointerDown: this.handleStandardView(streamAttributes.StandardView.TOP_RIGHT), disabled: this.standardViewsOff }), index.h(ViewCubeEdge, { length: this.boxLength, face1Side: "bottom", face1Edge: "left", face2Side: "left", face2Edge: "bottom", onPointerDown: this.handleStandardView(streamAttributes.StandardView.BOTTOM_RIGHT), disabled: this.standardViewsOff }), index.h(ViewCubeCorner, { length: this.boxLength, face1Side: "top", face1Corner: "bottom-left", face2Side: "front", face2Corner: "top-left", face3Side: "left", face3Corner: "top-right", onPointerDown: this.handleStandardView(streamAttributes.StandardView.TOP_FRONT_RIGHT), disabled: this.standardViewsOff }), index.h(ViewCubeCorner, { length: this.boxLength, face1Side: "top", face1Corner: "bottom-right", face2Side: "front", face2Corner: "top-right", face3Side: "right", face3Corner: "top-left", onPointerDown: this.handleStandardView(streamAttributes.StandardView.TOP_FRONT_LEFT), disabled: this.standardViewsOff }), index.h(ViewCubeCorner, { length: this.boxLength, face1Side: "bottom", face1Corner: "top-right", face2Side: "front", face2Corner: "bottom-right", face3Side: "right", face3Corner: "bottom-left", onPointerDown: this.handleStandardView(streamAttributes.StandardView.BOTTOM_FRONT_LEFT), disabled: this.standardViewsOff }), index.h(ViewCubeCorner, { length: this.boxLength, face1Side: "bottom", face1Corner: "top-left", face2Side: "front", face2Corner: "bottom-left", face3Side: "left", face3Corner: "bottom-right", onPointerDown: this.handleStandardView(streamAttributes.StandardView.BOTTOM_FRONT_RIGHT), disabled: this.standardViewsOff }), index.h(ViewCubeCorner, { length: this.boxLength, face1Side: "top", face1Corner: "top-right", face2Side: "back", face2Corner: "top-left", face3Side: "right", face3Corner: "top-right", onPointerDown: this.handleStandardView(streamAttributes.StandardView.TOP_BACK_LEFT), disabled: this.standardViewsOff }), index.h(ViewCubeCorner, { length: this.boxLength, face1Side: "top", face1Corner: "top-left", face2Side: "back", face2Corner: "top-right", face3Side: "left", face3Corner: "top-left", onPointerDown: this.handleStandardView(streamAttributes.StandardView.TOP_BACK_RIGHT), disabled: this.standardViewsOff }), index.h(ViewCubeCorner, { length: this.boxLength, face1Side: "bottom", face1Corner: "bottom-left", face2Side: "back", face2Corner: "bottom-right", face3Side: "left", face3Corner: "bottom-left", onPointerDown: this.handleStandardView(streamAttributes.StandardView.BOTTOM_BACK_RIGHT), disabled: this.standardViewsOff }), index.h(ViewCubeCorner, { length: this.boxLength, face1Side: "bottom", face1Corner: "bottom-right", face2Side: "back", face2Corner: "bottom-left", face3Side: "right", face3Corner: "bottom-right", onPointerDown: this.handleStandardView(streamAttributes.StandardView.BOTTOM_BACK_LEFT), disabled: this.standardViewsOff })))));
  }
  static get watchers() { return {
    "viewer": ["handleViewerChanged"]
  }; }
};
ViewerViewCube.style = viewerViewCubeCss;

exports.vertex_viewer_view_cube = ViewerViewCube;

//# sourceMappingURL=vertex-viewer-view-cube.cjs.entry.js.map