/*!
 * Copyright (c) 2025 Vertex Software LLC. All rights reserved.
 */
import { Component, h, Host, State } from '@stencil/core';
import classNames from 'classnames';
export class SceneTreeTableResizeDivider {
  constructor() {
    this.hovering = false;
    this.dragging = false;
    this.handlePointerDown = () => {
      this.dragging = true;
      window.addEventListener('pointerup', this.handlePointerUp);
    };
    this.handlePointerUp = () => {
      this.dragging = false;
      window.removeEventListener('pointerup', this.handlePointerUp);
    };
    this.handleCellPointerEnter = () => {
      this.hovering = true;
    };
    this.handleCellPointerLeave = () => {
      this.hovering = false;
    };
  }
  render() {
    const isHighlighted = !!this.hovering || !!this.dragging;
    return (h(Host, { onPointerDown: this.handlePointerDown, onPointerEnter: this.handleCellPointerEnter, onPointerLeave: this.handleCellPointerLeave, style: {
        height: isHighlighted ? '100%' : 'var(--header-height)',
        padding: isHighlighted
          ? '0 calc(var(--scene-tree-table-column-gap) / 2)'
          : 'calc(var(--header-height) / 8) calc(var(--scene-tree-table-column-gap) / 2)',
      } },
      h("slot", { name: "divider" },
        h("div", { class: classNames('divider', {
            highlighted: isHighlighted,
          }) }))));
  }
  static get is() { return "vertex-scene-tree-table-resize-divider"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["scene-tree-table-resize-divider.css"]
  }; }
  static get styleUrls() { return {
    "$": ["scene-tree-table-resize-divider.css"]
  }; }
  static get states() { return {
    "hovering": {},
    "dragging": {}
  }; }
}
//# sourceMappingURL=scene-tree-table-resize-divider.js.map