/*!
 * Copyright (c) 2025 Vertex Software LLC. All rights reserved.
 */
import { Component, h, Host, Prop } from '@stencil/core';
import classNames from 'classnames';
export class ViewerAnnotationCallout {
  constructor() {
    /**
     * The icon size to display.
     */
    this.iconSize = 'sm';
  }
  render() {
    return (h(Host, null,
      h("div", { class: classNames('content', this.iconSize), style: {
          borderColor: this.data.accentColor,
          backgroundColor: this.data.primaryColor,
        } },
        h("vertex-viewer-icon", { class: "icon", name: this.data.icon, size: this.iconSize, style: { color: this.data.accentColor } }))));
  }
  static get is() { return "vertex-viewer-annotation-callout"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["viewer-annotation-callout.css"]
  }; }
  static get styleUrls() { return {
    "$": ["viewer-annotation-callout.css"]
  }; }
  static get properties() { return {
    "data": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "CalloutAnnotationData",
        "resolved": "CalloutAnnotationData",
        "references": {
          "CalloutAnnotationData": {
            "location": "import",
            "path": "../../lib/annotations/annotation"
          }
        }
      },
      "required": true,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "The data that describes how to render the callout annotation."
      }
    },
    "iconSize": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "ViewerIconSize",
        "resolved": "\"lg\" | \"md\" | \"sm\" | undefined",
        "references": {
          "ViewerIconSize": {
            "location": "import",
            "path": "../viewer-icon/viewer-icon"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "The icon size to display."
      },
      "attribute": "icon-size",
      "reflect": false,
      "defaultValue": "'sm'"
    }
  }; }
}
//# sourceMappingURL=viewer-annotation-callout.js.map