/*!
 * Copyright (c) 2025 Vertex Software LLC. All rights reserved.
 */
import { Component, h, Prop } from '@stencil/core';
import classNames from 'classnames';
export class ViewerSpinner {
  constructor() {
    /**
     * The size of the spinner. Can be `'xs' | 'sm' | 'md' | 'lg' | undefined`. Predefined
     * sizes are set to:
     *
     *  * `xm`: 16px
     *  * `sm`: 24px
     *  * `md`: 32px
     *  * `lg`: 64px
     */
    this.size = 'md';
  }
  render() {
    return (h("div", { class: classNames('spinner', {
        ['xs']: this.size === 'xs',
        ['sm']: this.size === 'sm',
        ['md']: this.size === 'md',
        ['lg']: this.size === 'lg',
      }) },
      h("div", null),
      h("div", null),
      h("div", null),
      h("div", null)));
  }
  static get is() { return "vertex-viewer-spinner"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["viewer-spinner.css"]
  }; }
  static get styleUrls() { return {
    "$": ["viewer-spinner.css"]
  }; }
  static get properties() { return {
    "size": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "SpinnerSize",
        "resolved": "\"lg\" | \"md\" | \"sm\" | \"xs\" | undefined",
        "references": {
          "SpinnerSize": {
            "location": "local"
          }
        }
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": "The size of the spinner. Can be `'xs' | 'sm' | 'md' | 'lg' | undefined`. Predefined\nsizes are set to:\n\n * `xm`: 16px\n * `sm`: 24px\n * `md`: 32px\n * `lg`: 64px"
      },
      "attribute": "size",
      "reflect": false,
      "defaultValue": "'md'"
    }
  }; }
}
//# sourceMappingURL=viewer-spinner.js.map