/*!
 * Copyright (c) 2025 Vertex Software LLC. All rights reserved.
 */
import { Component, h, Prop } from '@stencil/core';
import classname from 'classnames';
export class ViewerToolbar {
  constructor() {
    /**
     * Specifies where the toolbar is positioned.
     */
    this.placement = 'bottom-center';
    this.direction = 'horizontal';
  }
  render() {
    const [vertical, horizontal] = this.placement.split('-');
    return (h("vertex-viewer-layer", { class: classname('layer', {
        'position-top': vertical === 'top',
        'position-middle': vertical === 'middle',
        'position-bottom': vertical === 'bottom',
        'position-left': horizontal === 'left',
        'position-center': horizontal === 'center',
        'position-right': horizontal === 'right',
      }) },
      h("div", { class: classname('inner', {
          vertical: this.direction === 'vertical',
          horizontal: this.direction === 'horizontal',
        }) },
        h("slot", null))));
  }
  static get is() { return "vertex-viewer-toolbar"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["viewer-toolbar.css"]
  }; }
  static get styleUrls() { return {
    "$": ["viewer-toolbar.css"]
  }; }
  static get properties() { return {
    "placement": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "ViewerToolbarPlacement",
        "resolved": "\"bottom-center\" | \"bottom-left\" | \"bottom-right\" | \"middle-left\" | \"middle-right\" | \"top-center\" | \"top-left\" | \"top-right\"",
        "references": {
          "ViewerToolbarPlacement": {
            "location": "import",
            "path": "./types"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Specifies where the toolbar is positioned."
      },
      "attribute": "placement",
      "reflect": false,
      "defaultValue": "'bottom-center'"
    },
    "direction": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "ViewerToolbarDirection",
        "resolved": "\"horizontal\" | \"vertical\"",
        "references": {
          "ViewerToolbarDirection": {
            "location": "import",
            "path": "./types"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "direction",
      "reflect": false,
      "defaultValue": "'horizontal'"
    }
  }; }
}
//# sourceMappingURL=viewer-toolbar.js.map