/*!
 * Copyright (c) 2025 Vertex Software LLC. All rights reserved.
 */
import { Rectangle, Vector3 } from '@vertexvis/geometry';
import { EventDispatcher } from '@vertexvis/utils';
import regl from 'regl';
import shapeBuilder from 'regl-shape';
import { axisPositions, rotationAxisPositions, } from '../../lib/transforms/axis-lines';
import { xAxisRotationPositions, yAxisRotationPositions, zAxisRotationPositions, } from '../../lib/transforms/axis-rotation';
import { xAxisArrowPositions, yAxisArrowPositions, zAxisArrowPositions, } from '../../lib/transforms/axis-translation';
import { computeDrawable2dBounds, } from '../../lib/transforms/drawable';
import { testDrawable } from '../../lib/transforms/hits';
import { AxisLine, RotationLine } from '../../lib/transforms/line';
import { TriangleMesh } from '../../lib/transforms/mesh';
import { ReglComponent } from '../../lib/webgl/regl-component';
export class TransformWidget extends ReglComponent {
  constructor(canvasElement, colors = {}, initialDisabledAxes = {}) {
    var _a, _b, _c, _d, _e, _f;
    super(canvasElement);
    this.disabledAxis = {
      xTranslation: false,
      yTranslation: false,
      zTranslation: false,
      xRotation: false,
      yRotation: false,
      zRotation: false,
    };
    this.axisLines = [];
    this.rotationLines = [];
    this.translationMeshes = [];
    this.rotationMeshes = [];
    this.hoveredChanged = new EventDispatcher();
    this.xArrowFillColor = colors.xArrow;
    this.yArrowFillColor = colors.yArrow;
    this.zArrowFillColor = colors.zArrow;
    this.hoveredArrowFillColor = colors.hovered;
    this.outlineColor = colors.outline;
    this.disabledAxis.xTranslation = (_a = initialDisabledAxes.xTranslation) !== null && _a !== void 0 ? _a : false;
    this.disabledAxis.yTranslation = (_b = initialDisabledAxes.yTranslation) !== null && _b !== void 0 ? _b : false;
    this.disabledAxis.zTranslation = (_c = initialDisabledAxes.zTranslation) !== null && _c !== void 0 ? _c : false;
    this.disabledAxis.xRotation = (_d = initialDisabledAxes.xRotation) !== null && _d !== void 0 ? _d : false;
    this.disabledAxis.yRotation = (_e = initialDisabledAxes.yRotation) !== null && _e !== void 0 ? _e : false;
    this.disabledAxis.zRotation = (_f = initialDisabledAxes.zRotation) !== null && _f !== void 0 ? _f : false;
  }
  dispose() {
    var _a;
    (_a = this.reglFrameDisposable) === null || _a === void 0 ? void 0 : _a.cancel();
  }
  /**
   * @internal - visible for testing
   */
  getDrawableElements() {
    return this.drawableElements;
  }
  getFullBounds() {
    return this.fullBounds;
  }
  boundsContainsPoint(point) {
    return (this.interactiveBounds != null &&
      this.frame != null &&
      Rectangle.containsPoints(this.interactiveBounds, point));
  }
  updateDisabledAxis(axis) {
    this.disabledAxis = Object.assign(Object.assign({}, this.disabledAxis), axis);
    this.updateDisabledOnDrawables();
  }
  updateCursor(cursor) {
    this.cursor = cursor;
    if (cursor != null && this.frame != null) {
      this.updateHovered();
    }
    else {
      this.clearHovered();
    }
  }
  updateTransform(transform) {
    var _a;
    this.transform = transform;
    if (transform != null && this.frame != null) {
      this.updateAndDraw();
    }
    else {
      this.clear();
      (_a = this.reglFrameDisposable) === null || _a === void 0 ? void 0 : _a.cancel();
      this.reglFrameDisposable = undefined;
    }
  }
  updateColors(colors = {}) {
    var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m;
    this.xArrowFillColor = (_a = colors.xArrow) !== null && _a !== void 0 ? _a : this.xArrowFillColor;
    this.yArrowFillColor = (_b = colors.yArrow) !== null && _b !== void 0 ? _b : this.yArrowFillColor;
    this.zArrowFillColor = (_c = colors.zArrow) !== null && _c !== void 0 ? _c : this.zArrowFillColor;
    this.hoveredArrowFillColor = (_d = colors.hovered) !== null && _d !== void 0 ? _d : this.hoveredArrowFillColor;
    this.outlineColor = (_e = colors.outline) !== null && _e !== void 0 ? _e : this.outlineColor;
    (_f = this.xArrow) === null || _f === void 0 ? void 0 : _f.updateFillColor(this.getXTranslationColor(), true);
    (_g = this.yArrow) === null || _g === void 0 ? void 0 : _g.updateFillColor(this.getYTranslationColor(), true);
    (_h = this.zArrow) === null || _h === void 0 ? void 0 : _h.updateFillColor(this.getZTranslationColor(), true);
    (_j = this.xRotation) === null || _j === void 0 ? void 0 : _j.updateFillColor(this.getXRotationColor(), true);
    (_k = this.yRotation) === null || _k === void 0 ? void 0 : _k.updateFillColor(this.getYRotationColor(), true);
    (_l = this.zRotation) === null || _l === void 0 ? void 0 : _l.updateFillColor(this.getZRotationColor(), true);
    (_m = this.hoveredElement) === null || _m === void 0 ? void 0 : _m.updateFillColor(this.hoveredArrowFillColor);
  }
  onHoveredChanged(listener) {
    return this.hoveredChanged.on(listener);
  }
  updateDisabledOnDrawables() {
    var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m;
    (_a = this.xRotation) === null || _a === void 0 ? void 0 : _a.setDisabled(this.disabledAxis.xRotation);
    (_b = this.xyRotationLine) === null || _b === void 0 ? void 0 : _b.setDisabled(this.disabledAxis.xRotation);
    (_c = this.xzRotationLine) === null || _c === void 0 ? void 0 : _c.setDisabled(this.disabledAxis.xRotation);
    (_d = this.yRotation) === null || _d === void 0 ? void 0 : _d.setDisabled(this.disabledAxis.yRotation);
    (_e = this.yzRotationLine) === null || _e === void 0 ? void 0 : _e.setDisabled(this.disabledAxis.yRotation);
    (_f = this.yxRotationLine) === null || _f === void 0 ? void 0 : _f.setDisabled(this.disabledAxis.yRotation);
    (_g = this.zRotation) === null || _g === void 0 ? void 0 : _g.setDisabled(this.disabledAxis.zRotation);
    (_h = this.zxRotationLine) === null || _h === void 0 ? void 0 : _h.setDisabled(this.disabledAxis.zRotation);
    (_j = this.zyRotationLine) === null || _j === void 0 ? void 0 : _j.setDisabled(this.disabledAxis.zRotation);
    (_k = this.xArrow) === null || _k === void 0 ? void 0 : _k.setDisabled(this.disabledAxis.xTranslation);
    (_l = this.yArrow) === null || _l === void 0 ? void 0 : _l.setDisabled(this.disabledAxis.yTranslation);
    (_m = this.zArrow) === null || _m === void 0 ? void 0 : _m.setDisabled(this.disabledAxis.zTranslation);
    this.updateColors();
  }
  updateHovered() {
    var _a;
    const previousHovered = this.hoveredElement;
    const currentFrame = this.frame;
    if (currentFrame != null) {
      this.hoveredElement = [...this.translationMeshes, ...this.rotationMeshes]
        .filter((el) => el.points.valid && !el.isDisabled())
        .find((m) => this.cursor != null
        ? testDrawable(m, currentFrame, this.viewport, this.cursor)
        : false);
      if (this.hoveredElement !== previousHovered) {
        this.hoveredChanged.emit(this.hoveredElement);
        (_a = this.hoveredElement) === null || _a === void 0 ? void 0 : _a.updateFillColor(this.hoveredArrowFillColor);
        previousHovered === null || previousHovered === void 0 ? void 0 : previousHovered.updateFillColor(previousHovered === null || previousHovered === void 0 ? void 0 : previousHovered.initialFillColor);
      }
    }
  }
  clearHovered() {
    const previousHovered = this.hoveredElement;
    this.hoveredElement = undefined;
    if (this.hoveredElement !== previousHovered) {
      this.hoveredChanged.emit(this.hoveredElement);
      previousHovered.updateFillColor(previousHovered.initialFillColor);
    }
  }
  hasData() {
    return this.transform != null;
  }
  createOrUpdateElements() {
    if (this.transform != null && this.frame != null) {
      if (this.xArrow == null || this.yArrow == null || this.zArrow == null) {
        this.createElements(this.transform, this.frame);
      }
      else {
        this.updateElements(this.transform, this.frame);
      }
      this.interactiveBounds = computeDrawable2dBounds(this.viewport, ...this.rotationMeshes, ...this.translationMeshes);
      this.fullBounds = computeDrawable2dBounds(this.viewport, ...this.rotationMeshes, ...this.translationMeshes, ...this.axisLines);
    }
  }
  createElements(transform, frame) {
    this.reglCommand = regl({
      canvas: this.canvasElement,
      extensions: 'angle_instanced_arrays',
    });
    const { createShape } = shapeBuilder(this.reglCommand);
    const triangleSize = this.computeTriangleSize(Vector3.fromMatrixPosition(transform), frame);
    this.xArrow = new TriangleMesh(createShape, 'x-translate', xAxisArrowPositions(transform, frame.scene.camera, triangleSize), this.outlineColor, this.getXTranslationColor());
    this.xRotation = new TriangleMesh(createShape, 'x-rotate', xAxisRotationPositions(transform, frame.scene.camera, triangleSize), this.outlineColor, this.getXRotationColor());
    this.xAxis = new AxisLine(createShape, 'x-axis', axisPositions(transform, frame.scene.camera, this.xArrow), this.outlineColor, this.getXTranslationColor());
    this.yArrow = new TriangleMesh(createShape, 'y-translate', yAxisArrowPositions(transform, frame.scene.camera, triangleSize), this.outlineColor, this.getYTranslationColor());
    this.yRotation = new TriangleMesh(createShape, 'y-rotate', yAxisRotationPositions(transform, frame.scene.camera, triangleSize), this.outlineColor, this.getYRotationColor());
    this.yAxis = new AxisLine(createShape, 'y-axis', axisPositions(transform, frame.scene.camera, this.yArrow), this.outlineColor, this.getYTranslationColor());
    this.zArrow = new TriangleMesh(createShape, 'z-translate', zAxisArrowPositions(transform, frame.scene.camera, triangleSize), this.outlineColor, this.getZTranslationColor());
    this.zAxis = new AxisLine(createShape, 'z-axis', axisPositions(transform, frame.scene.camera, this.zArrow), this.outlineColor, this.getZTranslationColor());
    this.zRotation = new TriangleMesh(createShape, 'z-rotate', zAxisRotationPositions(transform, frame.scene.camera, triangleSize), this.outlineColor, this.getZRotationColor());
    this.createRotationLines(createShape, transform, frame);
    this.axisLines = [this.xAxis, this.yAxis, this.zAxis];
    this.translationMeshes = [this.xArrow, this.yArrow, this.zArrow];
    this.rotationMeshes = [this.xRotation, this.yRotation, this.zRotation];
    this.updateDisabledOnDrawables();
    this.availableElements = [
      ...this.axisLines,
      ...this.rotationLines,
      ...this.translationMeshes,
      ...this.rotationMeshes,
    ];
  }
  getXRotationColor() {
    return this.xArrowFillColor;
  }
  getYRotationColor() {
    return this.yArrowFillColor;
  }
  getZRotationColor() {
    return this.zArrowFillColor;
  }
  getXTranslationColor() {
    return this.xArrowFillColor;
  }
  getYTranslationColor() {
    return this.yArrowFillColor;
  }
  getZTranslationColor() {
    return this.zArrowFillColor;
  }
  createRotationLines(createShape, transform, frame) {
    var _a, _b, _c, _d, _e, _f;
    const triangleSize = this.computeTriangleSize(Vector3.fromMatrixPosition(transform), frame);
    const xyRotationLinePoints = rotationAxisPositions(frame.scene.camera, this.xRotation, (_a = this.yArrow) === null || _a === void 0 ? void 0 : _a.points.worldTip, triangleSize);
    const xzRotationLinePoints = rotationAxisPositions(frame.scene.camera, this.xRotation, (_b = this.zArrow) === null || _b === void 0 ? void 0 : _b.points.worldTip, triangleSize);
    const yxRotationLinePoints = rotationAxisPositions(frame.scene.camera, this.yRotation, (_c = this.xArrow) === null || _c === void 0 ? void 0 : _c.points.worldTip, triangleSize);
    const yzRotationLinePoints = rotationAxisPositions(frame.scene.camera, this.yRotation, (_d = this.zArrow) === null || _d === void 0 ? void 0 : _d.points.worldTip, triangleSize);
    const zxRotationLinePoints = rotationAxisPositions(frame.scene.camera, this.zRotation, (_e = this.xArrow) === null || _e === void 0 ? void 0 : _e.points.worldTip, triangleSize);
    const zyRotationLinePoints = rotationAxisPositions(frame.scene.camera, this.zRotation, (_f = this.yArrow) === null || _f === void 0 ? void 0 : _f.points.worldTip, triangleSize);
    if (xyRotationLinePoints != null) {
      this.xyRotationLine = new RotationLine(createShape, 'xy-rotation-line', xyRotationLinePoints, this.outlineColor);
    }
    if (xzRotationLinePoints != null) {
      this.xzRotationLine = new RotationLine(createShape, 'xz-rotation-line', xzRotationLinePoints, this.outlineColor);
    }
    if (yxRotationLinePoints != null) {
      this.yxRotationLine = new RotationLine(createShape, 'yx-rotation-line', yxRotationLinePoints, this.outlineColor);
    }
    if (yzRotationLinePoints != null) {
      this.yzRotationLine = new RotationLine(createShape, 'yz-rotation-line', yzRotationLinePoints, this.outlineColor);
    }
    if (zxRotationLinePoints != null) {
      this.zxRotationLine = new RotationLine(createShape, 'zx-rotation-line', zxRotationLinePoints, this.outlineColor);
    }
    if (zyRotationLinePoints != null) {
      this.zyRotationLine = new RotationLine(createShape, 'zy-rotation-line', zyRotationLinePoints, this.outlineColor);
    }
    this.rotationLines = [
      this.xyRotationLine,
      this.xzRotationLine,
      this.yxRotationLine,
      this.yzRotationLine,
      this.zxRotationLine,
      this.zyRotationLine,
    ].filter((l) => l != null);
  }
  updateElements(transform, frame) {
    var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m, _o, _p, _q, _r, _s, _t;
    const triangleSize = this.computeTriangleSize(Vector3.fromMatrixPosition(transform), frame);
    if (this.xArrow != null) {
      this.xArrow.updatePoints(xAxisArrowPositions(transform, frame.scene.camera, triangleSize));
      (_a = this.xAxis) === null || _a === void 0 ? void 0 : _a.updatePoints(axisPositions(transform, frame.scene.camera, this.xArrow));
    }
    (_b = this.xRotation) === null || _b === void 0 ? void 0 : _b.updatePoints(xAxisRotationPositions(transform, frame.scene.camera, triangleSize));
    if (this.yArrow != null) {
      this.yArrow.updatePoints(yAxisArrowPositions(transform, frame.scene.camera, triangleSize));
      (_c = this.yAxis) === null || _c === void 0 ? void 0 : _c.updatePoints(axisPositions(transform, frame.scene.camera, this.yArrow));
    }
    (_d = this.yRotation) === null || _d === void 0 ? void 0 : _d.updatePoints(yAxisRotationPositions(transform, frame.scene.camera, triangleSize));
    if (this.zArrow != null) {
      this.zArrow.updatePoints(zAxisArrowPositions(transform, frame.scene.camera, triangleSize));
      (_e = this.zAxis) === null || _e === void 0 ? void 0 : _e.updatePoints(axisPositions(transform, frame.scene.camera, this.zArrow));
    }
    (_f = this.zRotation) === null || _f === void 0 ? void 0 : _f.updatePoints(zAxisRotationPositions(transform, frame.scene.camera, triangleSize));
    (_g = this.xyRotationLine) === null || _g === void 0 ? void 0 : _g.updatePoints(rotationAxisPositions(frame.scene.camera, this.xRotation, (_h = this.yArrow) === null || _h === void 0 ? void 0 : _h.points.worldTip, triangleSize));
    (_j = this.xzRotationLine) === null || _j === void 0 ? void 0 : _j.updatePoints(rotationAxisPositions(frame.scene.camera, this.xRotation, (_k = this.zArrow) === null || _k === void 0 ? void 0 : _k.points.worldTip, triangleSize));
    (_l = this.yxRotationLine) === null || _l === void 0 ? void 0 : _l.updatePoints(rotationAxisPositions(frame.scene.camera, this.yRotation, (_m = this.xArrow) === null || _m === void 0 ? void 0 : _m.points.worldTip, triangleSize));
    (_o = this.yzRotationLine) === null || _o === void 0 ? void 0 : _o.updatePoints(rotationAxisPositions(frame.scene.camera, this.yRotation, (_p = this.zArrow) === null || _p === void 0 ? void 0 : _p.points.worldTip, triangleSize));
    (_q = this.zxRotationLine) === null || _q === void 0 ? void 0 : _q.updatePoints(rotationAxisPositions(frame.scene.camera, this.zRotation, (_r = this.xArrow) === null || _r === void 0 ? void 0 : _r.points.worldTip, triangleSize));
    (_s = this.zyRotationLine) === null || _s === void 0 ? void 0 : _s.updatePoints(rotationAxisPositions(frame.scene.camera, this.zRotation, (_t = this.yArrow) === null || _t === void 0 ? void 0 : _t.points.worldTip, triangleSize));
  }
}
//# sourceMappingURL=widget.js.map