/*!
 * Copyright (c) 2025 Vertex Software LLC. All rights reserved.
 */
import { __asyncGenerator, __await } from "tslib";
import { grpc } from '@improbable-eng/grpc-web';
export function requestUnary(caller) {
  return new Promise((resolve, reject) => {
    caller((err, res) => {
      if (err != null) {
        reject(err);
      }
      else if (res != null) {
        resolve(res);
      }
      else {
        reject(new Error('Invalid gRPC response. Error and result are empty.'));
      }
    });
  });
}
export function requestPaged(fetch, next) {
  return __asyncGenerator(this, arguments, function* requestPaged_1() {
    let cursor = undefined;
    do {
      const res = yield __await(requestUnary(fetch(cursor)));
      yield yield __await(res);
      cursor = next(res);
    } while (cursor != null);
  });
}
export async function createMetadata(jwtProvider, deviceId) {
  const jwt = await jwtProvider();
  const meta = new grpc.Metadata({
    'jwt-context': JSON.stringify({
      jwt,
      metadata: { 'x-device-id': deviceId || '' },
    }),
  });
  return meta;
}
//# sourceMappingURL=grpc.js.map