/*!
 * Copyright (c) 2025 Vertex Software LLC. All rights reserved.
 */
import { Pager } from '@vertexvis/scene-view-protos/core/protos/paging_pb';
import { Uuid2l } from '@vertexvis/scene-view-protos/core/protos/uuid_pb';
import { ListPmiAnnotationsRequest, } from '@vertexvis/scene-view-protos/sceneview/protos/scene_view_api_pb';
import { UUID } from '@vertexvis/utils';
import { createMetadata, requestUnary } from '../grpc';
import { mapListPmiAnnotationsResponseOrThrow } from './mapper';
export class PmiController {
  constructor(client, jwtProvider, deviceIdProvider) {
    this.client = client;
    this.jwtProvider = jwtProvider;
    this.deviceIdProvider = deviceIdProvider;
  }
  async listAnnotations({ modelViewId, cursor, size = 50, } = {}) {
    const res = await requestUnary(async (handler) => {
      const deviceId = this.deviceIdProvider();
      const meta = await createMetadata(this.jwtProvider, deviceId);
      const req = new ListPmiAnnotationsRequest();
      if (modelViewId != null) {
        const { msb, lsb } = UUID.toMsbLsb(modelViewId);
        const id = new Uuid2l();
        id.setMsb(msb);
        id.setLsb(lsb);
        req.setModelViewId(id);
      }
      const page = new Pager();
      page.setLimit(size);
      if (cursor != null) {
        page.setCursor(cursor);
      }
      req.setPage(page);
      this.client.listPmiAnnotations(req, meta, handler);
    });
    return mapListPmiAnnotationsResponseOrThrow(res.toObject());
  }
}
//# sourceMappingURL=controller.js.map