/*!
 * Copyright (c) 2025 Vertex Software LLC. All rights reserved.
 */
import { Pager } from '@vertexvis/scene-tree-protos/core/protos/paging_pb';
import { Uuid2l } from '@vertexvis/scene-tree-protos/core/protos/uuid_pb';
import { ListSceneItemMetadataRequest, } from '@vertexvis/scene-view-protos/sceneview/protos/scene_view_api_pb';
import { UUID } from '@vertexvis/utils';
import { createMetadata, requestUnary } from '../grpc';
import { mapListSceneItemMetadataResponseOrThrow } from './mapper';
export class SceneItemController {
  constructor(client, jwtProvider, deviceIdProvider) {
    this.client = client;
    this.jwtProvider = jwtProvider;
    this.deviceIdProvider = deviceIdProvider;
  }
  async listSceneItemMetadata(itemId, listByOptions) {
    const res = await requestUnary(async (handler) => {
      const deviceId = this.deviceIdProvider();
      const meta = await createMetadata(this.jwtProvider, deviceId);
      const req = new ListSceneItemMetadataRequest();
      const { msb, lsb } = UUID.toMsbLsb(itemId);
      const id = new Uuid2l();
      id.setMsb(msb);
      id.setLsb(lsb);
      req.setItemId(id);
      const pager = new Pager();
      if (listByOptions.size != null) {
        pager.setLimit(listByOptions.size);
      }
      if (listByOptions.cursor != null) {
        pager.setCursor(listByOptions.cursor);
      }
      req.setPager(pager);
      this.client.listSceneItemMetadata(req, meta, handler);
    });
    return mapListSceneItemMetadataResponseOrThrow(res.toObject());
  }
}
//# sourceMappingURL=controller.js.map