/*!
 * Copyright (c) 2025 Vertex Software LLC. All rights reserved.
 */
import { Mapper as M } from '@vertexvis/utils';
import { mapCursor } from '../mappers';
const mapPropertyKey = M.defineMapper(M.read(M.requiredProp('name'), M.requiredProp('category')), ([name, category]) => ({ name, category }));
const mapGetStringValue = M.defineMapper(M.read(M.getProp('value')), ([value]) => ({
  type: 'string',
  value,
}));
const mapStringValue = M.mapProp('string', M.ifDefined(mapGetStringValue));
const mapGetLongValue = M.defineMapper(M.read(M.getProp('value')), ([value]) => ({
  type: 'long',
  value,
}));
const mapLongValue = M.mapProp('pb_long', M.ifDefined(mapGetLongValue));
const mapGetDoubleValue = M.defineMapper(M.read(M.getProp('value')), ([value]) => ({
  type: 'double',
  value,
}));
const mapDoubleValue = M.mapProp('pb_double', M.ifDefined(mapGetDoubleValue));
const mapGetTimestampValue = M.defineMapper(M.read(M.requiredProp('value')), ([value]) => ({
  type: 'timestamp',
  value: value,
}));
const mapTimestampValue = M.mapProp('date', M.ifDefined(mapGetTimestampValue));
const mapPropertyValue = M.compose(M.pickFirst(mapStringValue, mapLongValue, mapDoubleValue, mapTimestampValue), M.required('value'));
const mapEntriesList = M.defineMapper(M.read(M.requiredProp('id'), M.mapProp('key', M.ifDefined(mapPropertyKey)), M.mapProp('value', M.ifDefined(mapPropertyValue))), ([id, key, value]) => ({ id, key, value }));
const mapListSceneItemMetadataResposne = M.defineMapper(M.read(M.mapProp('cursor', mapCursor), M.mapRequiredProp('entriesList', M.mapArray(mapEntriesList))), ([cursor, entries]) => ({
  paging: {
    next: cursor,
  },
  entries,
}));
export const mapListSceneItemMetadataResponseOrThrow = M.ifInvalidThrow(mapListSceneItemMetadataResposne);
//# sourceMappingURL=mapper.js.map