/*!
 * Copyright (c) 2025 Vertex Software LLC. All rights reserved.
 */
// The source of these values are from:
// https://github.com/Vertexvis/rendering-worker-service/blob/fc1c864d1da4b5eb12794478dc720fa046412ee2/src/embree.isph#L163
/**
 * An enumeration of the possible types of entities in a frame.
 */
export var EntityType;
(function (EntityType) {
  /**
   * A value that represents the presence of a cross-section.
   */
  EntityType[EntityType["CROSS_SECTION"] = 255] = "CROSS_SECTION";
  /**
   * A value that represents the presence of an edge with BREP.
   */
  EntityType[EntityType["PRECISE_EDGE"] = 224] = "PRECISE_EDGE";
  /**
   * A value that represents the presence of a surface with BREP.
   */
  EntityType[EntityType["PRECISE_SURFACE"] = 192] = "PRECISE_SURFACE";
  /**
   * A value that represents the presence of an edge without BREP.
   */
  EntityType[EntityType["IMPRECISE_EDGE"] = 160] = "IMPRECISE_EDGE";
  /**
   * A value that represents the presence of a surface without BREP.
   */
  EntityType[EntityType["IMPRECISE_SURFACE"] = 128] = "IMPRECISE_SURFACE";
  /**
   * A value that represents the presence of geometry without BREP.
   */
  EntityType[EntityType["GENERIC_GEOMETRY"] = 96] = "GENERIC_GEOMETRY";
  /**
   * A value that represents the absence of geometry.
   */
  EntityType[EntityType["NO_GEOMETRY"] = 0] = "NO_GEOMETRY";
})(EntityType || (EntityType = {}));
//# sourceMappingURL=entities.js.map