/*!
 * Copyright (c) 2025 Vertex Software LLC. All rights reserved.
 */
import { g as __asyncGenerator, h as __await } from './tslib.es6.js';
import { a as grpcWebClient_umd } from './wrappers_pb.js';

function requestUnary(caller) {
  return new Promise((resolve, reject) => {
    caller((err, res) => {
      if (err != null) {
        reject(err);
      }
      else if (res != null) {
        resolve(res);
      }
      else {
        reject(new Error('Invalid gRPC response. Error and result are empty.'));
      }
    });
  });
}
function requestPaged(fetch, next) {
  return __asyncGenerator(this, arguments, function* requestPaged_1() {
    let cursor = undefined;
    do {
      const res = yield __await(requestUnary(fetch(cursor)));
      yield yield __await(res);
      cursor = next(res);
    } while (cursor != null);
  });
}
async function createMetadata(jwtProvider, deviceId) {
  const jwt = await jwtProvider();
  const meta = new grpcWebClient_umd.grpc.Metadata({
    'jwt-context': JSON.stringify({
      jwt,
      metadata: { 'x-device-id': deviceId || '' },
    }),
  });
  return meta;
}

export { requestPaged as a, createMetadata as c, requestUnary as r };

//# sourceMappingURL=grpc.js.map