/*!
 * Copyright (c) 2025 Vertex Software LLC. All rights reserved.
 */
import { m as mapper } from './browser.esm.js';
import { l as fromPbUuid2l, m as mapCursor, n as toPbJsUuid2l } from './streamAttributes.js';

const mapModelView = mapper.defineMapper(mapper.read(mapper.mapRequiredProp('id', fromPbUuid2l), mapper.getProp('displayName'), mapper.mapRequiredProp('partRevisionId', fromPbUuid2l)), ([id, displayName, partRevisionId]) => ({
  id,
  displayName,
  partRevisionId,
}));
const mapListItemModelViewsResponse = mapper.defineMapper(mapper.read(mapper.mapProp('modelViewsList', mapper.mapArray(mapModelView)), mapper.mapProp('nextPageCursor', mapCursor)), ([modelViews, next]) => ({ modelViews, paging: { next } }));
const mapListItemModelViewsResponseOrThrow = mapper.ifInvalidThrow(mapListItemModelViewsResponse);
const mapItemModelView = mapper.defineMapper(mapper.read(mapper.mapProp('modelViewId', toPbJsUuid2l), mapper.mapProp('sceneItemId', toPbJsUuid2l)), ([modelViewId, sceneItemId]) => ({ modelViewId, sceneItemId }));
const mapItemModelViewOrThrow = mapper.ifInvalidThrow(mapItemModelView);

const mapPmiAnnotation = mapper.defineMapper(mapper.read(mapper.mapRequiredProp('id', fromPbUuid2l), mapper.getProp('displayName')), ([id, displayName]) => ({ id, displayName }));
const mapListPmiAnnotationsResponse = mapper.defineMapper(mapper.read(mapper.mapProp('annotationsList', mapper.mapArray(mapPmiAnnotation)), mapper.mapProp('nextPageCursor', mapCursor)), ([annotations, next]) => ({ annotations, paging: { next } }));
const mapListPmiAnnotationsResponseOrThrow = mapper.ifInvalidThrow(mapListPmiAnnotationsResponse);

export { mapItemModelViewOrThrow as a, mapListPmiAnnotationsResponseOrThrow as b, mapListItemModelViewsResponseOrThrow as m };

//# sourceMappingURL=mapper2.js.map