/*!
 * Copyright (c) 2025 Vertex Software LLC. All rights reserved.
 */
import { proxyCustomElement, HTMLElement, h, Host } from '@stencil/core/internal/client';
import { c as classnames } from './index2.js';

const sceneTreeTableResizeDividerCss = ":host{pointer-events:auto;display:flex;align-items:center;box-sizing:border-box;cursor:col-resize}.divider{width:1px;height:100%;background-color:var(--neutral-300);cursor:col-resize}.divider.highlighted{background-color:var(--blue-600)}";

const SceneTreeTableResizeDivider = /*@__PURE__*/ proxyCustomElement(class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.__attachShadow();
    this.hovering = false;
    this.dragging = false;
    this.handlePointerDown = () => {
      this.dragging = true;
      window.addEventListener('pointerup', this.handlePointerUp);
    };
    this.handlePointerUp = () => {
      this.dragging = false;
      window.removeEventListener('pointerup', this.handlePointerUp);
    };
    this.handleCellPointerEnter = () => {
      this.hovering = true;
    };
    this.handleCellPointerLeave = () => {
      this.hovering = false;
    };
  }
  render() {
    const isHighlighted = !!this.hovering || !!this.dragging;
    return (h(Host, { onPointerDown: this.handlePointerDown, onPointerEnter: this.handleCellPointerEnter, onPointerLeave: this.handleCellPointerLeave, style: {
        height: isHighlighted ? '100%' : 'var(--header-height)',
        padding: isHighlighted
          ? '0 calc(var(--scene-tree-table-column-gap) / 2)'
          : 'calc(var(--header-height) / 8) calc(var(--scene-tree-table-column-gap) / 2)',
      } }, h("slot", { name: "divider" }, h("div", { class: classnames('divider', {
        highlighted: isHighlighted,
      }) }))));
  }
  static get style() { return sceneTreeTableResizeDividerCss; }
}, [1, "vertex-scene-tree-table-resize-divider", {
    "hovering": [32],
    "dragging": [32]
  }]);
function defineCustomElement$1() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["vertex-scene-tree-table-resize-divider"];
  components.forEach(tagName => { switch (tagName) {
    case "vertex-scene-tree-table-resize-divider":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, SceneTreeTableResizeDivider);
      }
      break;
  } });
}
defineCustomElement$1();

const VertexSceneTreeTableResizeDivider = SceneTreeTableResizeDivider;
const defineCustomElement = defineCustomElement$1;

export { VertexSceneTreeTableResizeDivider, defineCustomElement };

//# sourceMappingURL=vertex-scene-tree-table-resize-divider.js.map