/*!
 * Copyright (c) 2025 Vertex Software LLC. All rights reserved.
 */
import { proxyCustomElement, HTMLElement, h, Host } from '@stencil/core/internal/client';
import { c as classnames } from './index2.js';
import { d as defineCustomElement$2 } from './viewer-icon.js';

const viewerAnnotationCalloutCss = ":host{display:block;--viewer-annotation-callout-primary-color:var(--blue-700);--viewer-annotation-callout-accent-color:var(--white)}.content{display:flex;align-items:center;box-sizing:border-box;justify-content:center;background-color:var(--viewer-annotation-callout-primary-color);border:1px solid var(--viewer-annotation-callout-accent-color)}.content.sm{border-radius:14px;width:28px;height:28px}.content.md{border-radius:19px;width:38px;height:38px}.content.lg{border-radius:24px;width:48px;height:48px}.icon{color:var(--viewer-annotation-callout-accent-color)}";

const ViewerAnnotationCallout = /*@__PURE__*/ proxyCustomElement(class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.__attachShadow();
    /**
     * The icon size to display.
     */
    this.iconSize = 'sm';
  }
  render() {
    return (h(Host, null, h("div", { class: classnames('content', this.iconSize), style: {
        borderColor: this.data.accentColor,
        backgroundColor: this.data.primaryColor,
      } }, h("vertex-viewer-icon", { class: "icon", name: this.data.icon, size: this.iconSize, style: { color: this.data.accentColor } }))));
  }
  static get style() { return viewerAnnotationCalloutCss; }
}, [1, "vertex-viewer-annotation-callout", {
    "data": [16],
    "iconSize": [1, "icon-size"]
  }]);
function defineCustomElement$1() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["vertex-viewer-annotation-callout", "vertex-viewer-icon"];
  components.forEach(tagName => { switch (tagName) {
    case "vertex-viewer-annotation-callout":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, ViewerAnnotationCallout);
      }
      break;
    case "vertex-viewer-icon":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
  } });
}
defineCustomElement$1();

const VertexViewerAnnotationCallout = ViewerAnnotationCallout;
const defineCustomElement = defineCustomElement$1;

export { VertexViewerAnnotationCallout, defineCustomElement };

//# sourceMappingURL=vertex-viewer-annotation-callout.js.map