/*!
 * Copyright (c) 2025 Vertex Software LLC. All rights reserved.
 */
import { proxyCustomElement, HTMLElement, h, Host } from '@stencil/core/internal/client';

const viewerLayerCss = ":host{pointer-events:none;overflow:hidden}:host(:not([stretch-off])){position:absolute;left:0;right:0;top:0;bottom:0}";

const ViewerLayer = /*@__PURE__*/ proxyCustomElement(class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.__attachShadow();
    /**
     * Indicates if the layer should stretch to fill the size of its container's
     * nearest positioned parent.
     */
    this.stretchOff = false;
  }
  /**
   * @ignore
   */
  render() {
    return (h(Host, null, h("slot", null)));
  }
  get hostEl() { return this; }
  static get style() { return viewerLayerCss; }
}, [1, "vertex-viewer-layer", {
    "stretchOff": [516, "stretch-off"]
  }]);
function defineCustomElement() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["vertex-viewer-layer"];
  components.forEach(tagName => { switch (tagName) {
    case "vertex-viewer-layer":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, ViewerLayer);
      }
      break;
  } });
}
defineCustomElement();

export { ViewerLayer as V, defineCustomElement as d };

//# sourceMappingURL=viewer-layer.js.map