/*!
 * Copyright (c) 2025 Vertex Software LLC. All rights reserved.
 */
import { proxyCustomElement, HTMLElement, h } from '@stencil/core/internal/client';
import { c as classnames } from './index2.js';

const viewerSpinnerCss = ".spinner{position:relative;height:16px;width:16px}.spinner div{position:absolute;display:block;animation:spinner 1.2s cubic-bezier(0.5, 0, 0.5, 1) infinite;border-radius:50%;border-style:solid;box-sizing:border-box;border-color:var(--neutral-800) transparent transparent transparent;border-width:1px;margin:0}.spinner div:nth-child(1){animation-delay:-0.45s}.spinner div:nth-child(2){animation-delay:-0.3s}.spinner div:nth-child(3){animation-delay:-0.15s}.spinner.xs{height:16px;width:16px}.spinner.xs div{border-width:1px;height:16px;width:16px;margin:0}.spinner.sm{height:24px;width:24px}.spinner.sm div{border-width:3px;height:18px;width:18px;margin:2px}.spinner.md{height:32px;width:32px}.spinner.md div{border-width:3px;height:32px;width:32px;margin:2px}.spinner.lg{height:64px;width:64px}.spinner.lg div{border-width:6px;height:52px;width:52px;margin:6px}@keyframes spinner{0%{transform:rotate(0deg)}100%{transform:rotate(360deg)}}";

const ViewerSpinner = /*@__PURE__*/ proxyCustomElement(class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.__attachShadow();
    /**
     * The size of the spinner. Can be `'xs' | 'sm' | 'md' | 'lg' | undefined`. Predefined
     * sizes are set to:
     *
     *  * `xm`: 16px
     *  * `sm`: 24px
     *  * `md`: 32px
     *  * `lg`: 64px
     */
    this.size = 'md';
  }
  render() {
    return (h("div", { class: classnames('spinner', {
        ['xs']: this.size === 'xs',
        ['sm']: this.size === 'sm',
        ['md']: this.size === 'md',
        ['lg']: this.size === 'lg',
      }) }, h("div", null), h("div", null), h("div", null), h("div", null)));
  }
  static get style() { return viewerSpinnerCss; }
}, [1, "vertex-viewer-spinner", {
    "size": [1]
  }]);
function defineCustomElement() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["vertex-viewer-spinner"];
  components.forEach(tagName => { switch (tagName) {
    case "vertex-viewer-spinner":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, ViewerSpinner);
      }
      break;
  } });
}
defineCustomElement();

export { ViewerSpinner as V, defineCustomElement as d };

//# sourceMappingURL=viewer-spinner.js.map