/*!
 * Copyright (c) 2025 Vertex Software LLC. All rights reserved.
 */
import { proxyCustomElement, HTMLElement, h } from '@stencil/core/internal/client';
import { c as classnames } from './index2.js';
import { d as defineCustomElement$1 } from './viewer-layer.js';

const viewerToolbarCss = ".layer{padding:1rem;display:flex}.layer.position-top{align-items:flex-start}.layer.position-middle{align-items:center}.layer.position-bottom{align-items:flex-end}.layer.position-left{justify-content:flex-start}.layer.position-center{justify-content:center}.layer.position-right{justify-content:flex-end}.inner{display:flex}.inner.vertical{flex-direction:column}.inner.horizonal{flex-direction:row}::slotted(*){pointer-events:initial}";

const ViewerToolbar = /*@__PURE__*/ proxyCustomElement(class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.__attachShadow();
    /**
     * Specifies where the toolbar is positioned.
     */
    this.placement = 'bottom-center';
    this.direction = 'horizontal';
  }
  render() {
    const [vertical, horizontal] = this.placement.split('-');
    return (h("vertex-viewer-layer", { class: classnames('layer', {
        'position-top': vertical === 'top',
        'position-middle': vertical === 'middle',
        'position-bottom': vertical === 'bottom',
        'position-left': horizontal === 'left',
        'position-center': horizontal === 'center',
        'position-right': horizontal === 'right',
      }) }, h("div", { class: classnames('inner', {
        vertical: this.direction === 'vertical',
        horizontal: this.direction === 'horizontal',
      }) }, h("slot", null))));
  }
  static get style() { return viewerToolbarCss; }
}, [1, "vertex-viewer-toolbar", {
    "placement": [1],
    "direction": [1]
  }]);
function defineCustomElement() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["vertex-viewer-toolbar", "vertex-viewer-layer"];
  components.forEach(tagName => { switch (tagName) {
    case "vertex-viewer-toolbar":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, ViewerToolbar);
      }
      break;
    case "vertex-viewer-layer":
      if (!customElements.get(tagName)) {
        defineCustomElement$1();
      }
      break;
  } });
}
defineCustomElement();

export { ViewerToolbar as V, defineCustomElement as d };

//# sourceMappingURL=viewer-toolbar.js.map