/*!
 * Copyright (c) 2025 Vertex Software LLC. All rights reserved.
 */
import { r as registerInstance, h, H as Host } from './index-fef00dee.js';
import { c as classnames } from './index-eb6950b9.js';
import './_commonjsHelpers-6e425ac3.js';

const sceneTreeTableResizeDividerCss = ":host{pointer-events:auto;display:flex;align-items:center;box-sizing:border-box;cursor:col-resize}.divider{width:1px;height:100%;background-color:var(--neutral-300);cursor:col-resize}.divider.highlighted{background-color:var(--blue-600)}";

const SceneTreeTableResizeDivider = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.hovering = false;
    this.dragging = false;
    this.handlePointerDown = () => {
      this.dragging = true;
      window.addEventListener('pointerup', this.handlePointerUp);
    };
    this.handlePointerUp = () => {
      this.dragging = false;
      window.removeEventListener('pointerup', this.handlePointerUp);
    };
    this.handleCellPointerEnter = () => {
      this.hovering = true;
    };
    this.handleCellPointerLeave = () => {
      this.hovering = false;
    };
  }
  render() {
    const isHighlighted = !!this.hovering || !!this.dragging;
    return (h(Host, { onPointerDown: this.handlePointerDown, onPointerEnter: this.handleCellPointerEnter, onPointerLeave: this.handleCellPointerLeave, style: {
        height: isHighlighted ? '100%' : 'var(--header-height)',
        padding: isHighlighted
          ? '0 calc(var(--scene-tree-table-column-gap) / 2)'
          : 'calc(var(--header-height) / 8) calc(var(--scene-tree-table-column-gap) / 2)',
      } }, h("slot", { name: "divider" }, h("div", { class: classnames('divider', {
        highlighted: isHighlighted,
      }) }))));
  }
};
SceneTreeTableResizeDivider.style = sceneTreeTableResizeDividerCss;

export { SceneTreeTableResizeDivider as vertex_scene_tree_table_resize_divider };

//# sourceMappingURL=vertex-scene-tree-table-resize-divider.entry.js.map