/*!
 * Copyright (c) 2025 Vertex Software LLC. All rights reserved.
 */
import { r as registerInstance, h, H as Host } from './index-fef00dee.js';
import { c as classnames } from './index-eb6950b9.js';
import './_commonjsHelpers-6e425ac3.js';

const viewerButtonCss = ":host{cursor:pointer}.viewer-button{align-items:center;background:none;border:none;color:inherit;cursor:inherit;display:flex;padding:0}";

const ViewerButton = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
  }
  render() {
    return (h(Host, null, h("button", { class: "viewer-button" }, h("slot", null))));
  }
};
ViewerButton.style = viewerButtonCss;

const viewerToolbarCss = ".layer{padding:1rem;display:flex}.layer.position-top{align-items:flex-start}.layer.position-middle{align-items:center}.layer.position-bottom{align-items:flex-end}.layer.position-left{justify-content:flex-start}.layer.position-center{justify-content:center}.layer.position-right{justify-content:flex-end}.inner{display:flex}.inner.vertical{flex-direction:column}.inner.horizonal{flex-direction:row}::slotted(*){pointer-events:initial}";

const ViewerToolbar = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    /**
     * Specifies where the toolbar is positioned.
     */
    this.placement = 'bottom-center';
    this.direction = 'horizontal';
  }
  render() {
    const [vertical, horizontal] = this.placement.split('-');
    return (h("vertex-viewer-layer", { class: classnames('layer', {
        'position-top': vertical === 'top',
        'position-middle': vertical === 'middle',
        'position-bottom': vertical === 'bottom',
        'position-left': horizontal === 'left',
        'position-center': horizontal === 'center',
        'position-right': horizontal === 'right',
      }) }, h("div", { class: classnames('inner', {
        vertical: this.direction === 'vertical',
        horizontal: this.direction === 'horizontal',
      }) }, h("slot", null))));
  }
};
ViewerToolbar.style = viewerToolbarCss;

const viewerToolbarGroupCss = ".inner{display:flex;align-items:center;margin:auto}.inner.vertical{flex-direction:column}.inner.horizontal{flex-direction:row}";

const ViewerToolbarGroup = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.direction = 'horizontal';
  }
  render() {
    return (h("div", { class: classnames('inner', {
        horizontal: this.direction === 'horizontal',
        vertical: this.direction === 'vertical',
      }) }, h("slot", null)));
  }
};
ViewerToolbarGroup.style = viewerToolbarGroupCss;

export { ViewerButton as vertex_viewer_button, ViewerToolbar as vertex_viewer_toolbar, ViewerToolbarGroup as vertex_viewer_toolbar_group };

//# sourceMappingURL=vertex-viewer-button_3.entry.js.map