/*!
 * Copyright (c) 2025 Vertex Software LLC. All rights reserved.
 */
import { r as registerInstance, h } from './index-fef00dee.js';

const viewerDefaultToolbarCss = ":host{--viewer-toolbar-group-gap:0.5rem;--viewer-toolbar-group-background:rgba(245, 245, 245, 0.95);--viewer-toolbar-group-border-radius:0.25rem;--viewer-toolbar-group-box-shadow:-1px 0 2px rgba(0, 0, 0, 0.12),\n    1px 0 2px rgba(0, 0, 0, 0.13);--viewer-toolbar-group-padding:0.25rem;--viewer-toolbar-group-item-gap:0.25rem}.group{background:var(--viewer-toolbar-group-background);border-radius:var(--viewer-toolbar-group-border-radius);box-shadow:var(--viewer-toolbar-group-box-shadow);padding:var(--viewer-toolbar-group-padding)}.group[data-direction='horizontal']:not(:first-child){margin-left:var(--viewer-toolbar-group-gap)}.group[data-direction='horizontal'] .group-item:not(:first-child){margin-left:var(--viewer-toolbar-group-item-gap)}.group[data-direction='vertical']:not(:first-child){margin-top:var(--viewer-toolbar-group-gap)}.group[data-direction='vertical'] .group-item:not(:first-child){margin-top:var(--viewer-toolbar-group-item-gap)}.btn{color:var(--neutral-800);padding:0.125rem;border-radius:0.125rem}.btn:hover{background:var(--neutral-300)}";

const ViewerDefaultToolbar = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    /**
     * Specifies where the toolbar is positioned.
     */
    this.placement = 'bottom-center';
    /**
     * Specifies the direction that UI elements are placed.
     */
    this.direction = 'horizontal';
    /**
     * Indicates whether animations will be used when performing camera
     * operations. Defaults to `true`.
     */
    this.animationsDisabled = false;
    /**
     * The duration of animations, in milliseconds. Defaults to `1000`.
     */
    this.animationMs = 1000;
  }
  render() {
    return (h("vertex-viewer-toolbar", { placement: this.placement, direction: this.direction }, h("vertex-viewer-toolbar-group", { class: "group", direction: this.direction, "data-direction": this.direction }, h("vertex-viewer-button", { class: "group-item btn", "data-test-id": "fit-all-btn", onClick: () => this.viewAll() }, h("vertex-viewer-icon", { class: "icon", name: "fit-all", size: "md" })))));
  }
  async viewAll() {
    var _a;
    const scene = await ((_a = this.viewer) === null || _a === void 0 ? void 0 : _a.scene());
    const animation = this.animationsDisabled
      ? undefined
      : { milliseconds: this.animationMs };
    scene === null || scene === void 0 ? void 0 : scene.camera().viewAll().render({ animation });
  }
};
ViewerDefaultToolbar.style = viewerDefaultToolbarCss;

export { ViewerDefaultToolbar as vertex_viewer_default_toolbar };

//# sourceMappingURL=vertex-viewer-default-toolbar.entry.js.map