import { EventEmitter, h } from '../../stencil-public-runtime';
import { Rectangle } from '@vertexvis/geometry';
import { MarkupInteraction } from '../../lib/types/markup';
/**
 * The supported markup modes.
 *
 * @see {@link ViewerMarkupCircleMode.mode} - For more details about modes.
 */
export declare type ViewerMarkupCircleMode = 'edit' | 'create' | '';
export declare class ViewerMarkupCircle {
  /**
   * The bounds of the circle. Can either be an instance of a `Rectangle` or
   * a JSON string representation in the format of `[x, y, width, height]` or
   * `{"x": 0, "y": 0, "width": 10, "height": 10}`.
   *
   * Bounds are expected to have relative coordinates, with `[x, y]` from `[-0.5, 0.5]`
   * and `[width, height]` from `[0, 1]`, e.g. `[0, 0, 0.25, 0.25]`corresponds to a circle
   * with a diameter of one fourth the viewport's smallest size in the center of the viewport.
   */
  bounds?: Rectangle.Rectangle;
  /**
   * The bounds of the circle. Can either be an instance of a `Rectangle` or
   * a JSON string representation in the format of `[x, y, width, height]` or
   * `{"x": 0, "y": 0, "width": 0.1, "height": 0.1}`.
   *
   * Bounds are expected to have relative coordinates, with `[x, y]` from `[-0.5, 0.5]`
   * and `[width, height]` from `[0, 1]`, e.g. `[0, 0, 0.25, 0.25]`corresponds to a circle
   * with a diameter of one fourth the viewport's smallest size in the center of the viewport.
   */
  boundsJson?: string;
  /**
   * A mode that specifies how the markup component should behave. When
   * unset, the component will not respond to interactions with the handles.
   * When `edit`, the markup anchors are interactive and the user is able
   * to reposition them. When `create`, anytime the user clicks on the canvas,
   * a new markup will be performed.
   */
  mode: ViewerMarkupCircleMode;
  /**
   * The viewer to connect to markups.
   *
   * This property will automatically be set when a child of a
   * `<vertex-viewer-markup>` or `<vertex-viewer>` element.
   */
  viewer?: HTMLVertexViewerElement;
  /**
   * An event that is dispatched anytime the user begins interacting with the
   * markup.
   */
  interactionBegin: EventEmitter<void>;
  /**
   * An event that is dispatched when the user has finished interacting with the
   * markup.
   */
  interactionEnd: EventEmitter<MarkupInteraction>;
  /**
   * An event that is dispatched when this markup element is in view
   * mode (`this.mode === ""`), and it completes a rerender.
   */
  viewRendered: EventEmitter<void>;
  private hostEl;
  private elementBounds?;
  private interactionHandler;
  private registeredHandler?;
  /**
   * @ignore
   */
  protected componentWillLoad(): void;
  protected componentDidLoad(): void;
  protected componentDidRender(): void;
  protected disconnectedCallback(): void;
  dispose(): Promise<void>;
  /**
   * @ignore
   */
  protected handleViewerChanged(newViewer?: HTMLVertexViewerElement): Promise<void>;
  protected handleBoundsJsonChange(): void;
  protected handleModeChange(): void;
  private updateViewport;
  private updateBoundsFromProps;
  render(): h.JSX.IntrinsicElements;
  private handleWindowPointerDown;
  private handleTouchStart;
}
