import { EventEmitter, h } from '../../stencil-public-runtime';
import { Markup } from '../../lib/types/markup';
import { LineAnchorStyle } from '../viewer-markup-arrow/utils';
/**
 * The types of markup that can be performed by this tool.
 */
export declare type ViewerMarkupToolType = 'arrow' | 'circle' | 'freeform';
export declare class ViewerMarkupTool {
  /**
   * An HTML template that describes the HTML to use for new arrow
   * markup. It's expected that the template contains a
   * `<vertex-viewer-markup-arrow>`.
   */
  arrowTemplateId?: string;
  /**
   * An HTML template that describes the HTML to use for new circle
   * markup. It's expected that the template contains a
   * `<vertex-viewer-markup-circle>`.
   */
  circleTemplateId?: string;
  /**
   * An HTML template that describes the HTML to use for new freeform
   * markup. It's expected that the template contains a
   * `<vertex-viewer-markup-freeform>`.
   */
  freeformTemplateId?: string;
  /**
   * The type of markup.
   *
   * This property will automatically be set when a child of a
   * `<vertex-viewer-markup>` element.
   */
  tool: ViewerMarkupToolType;
  /**
   * Disables markups.
   *
   * This property will automatically be set when a child of a
   * `<vertex-viewer-markup>` element.
   */
  disabled: boolean;
  /**
   * The viewer to connect to markup.
   *
   * This property will automatically be set when a child of a
   * `<vertex-viewer-markup>` or `<vertex-viewer>` element.
   */
  viewer?: HTMLVertexViewerElement;
  /**
   * The style of the starting anchor. This defaults to none.
   */
  startLineAnchorStyle: LineAnchorStyle;
  /**
   * The style of the ending anchor. This defaults to 'arrow-triangle.'
   */
  endLineAnchorStyle: LineAnchorStyle;
  /**
   * An event that is dispatched when a user begins a new markup.
   */
  markupBegin: EventEmitter<void>;
  /**
   * An event that is dispatched when a user has finished their markup.
   */
  markupEnd: EventEmitter<Markup>;
  private hostEl;
  /**
   * Captures internal state that you want to preserve across dev refreshes, but
   * don't want to trigger a render when the state changes.
   */
  private stateMap;
  protected handleViewerChanged(): Promise<void>;
  /**
   * @ignore
   */
  protected handleToolChanged(): void;
  /**
   * @ignore
   */
  protected handleArrowTemplateIdChanged(): void;
  /**
   * @ignore
   */
  protected handleCircleTemplateIdChanged(): void;
  /**
   * @ignore
   */
  protected handleFreeformTemplateIdChanged(): void;
  /**
   * @ignore
   */
  protected handleDisabledChanged(): void;
  /**
   * @ignore
   */
  protected handleStartLineAnchorStyleChanged(): void;
  /**
   * @ignore
   */
  protected handleEndLineAnchorStyleChanged(): void;
  /**
   * @ignore
   */
  protected componentDidLoad(): void;
  /**
   * Resets the state of the internally managed markup element
   * to allow for creating a new markup. This state is automatically
   * managed when this element is placed as a child of a
   * `<vertex-viewer-markup>` element.
   */
  reset(): Promise<void>;
  /**
   * @ignore
   */
  protected render(): h.JSX.IntrinsicElements;
  private createArrowMarkupElement;
  private createCircleMarkupElement;
  private createFreeformMarkupElement;
  private createNewMarkupElement;
  private updateMarkupElement;
  private handleMarkupInteractionBegin;
  private handleMarkupInteractionEnd;
}
