import { Matrix4 } from '@vertexvis/geometry';
import { Point, Rectangle } from '@vertexvis/geometry';
import { Color, Disposable, Listener } from '@vertexvis/utils';
import { Drawable } from '../../lib/transforms/drawable';
import { ReglComponent } from '../../lib/webgl/regl-component';
export interface DrawableElementColors {
  xArrow?: Color.Color | string;
  yArrow?: Color.Color | string;
  zArrow?: Color.Color | string;
  hovered?: Color.Color | string;
  outline?: Color.Color | string;
}
export interface DisabledAxis {
  xRotation: boolean;
  yRotation: boolean;
  zRotation: boolean;
  xTranslation: boolean;
  yTranslation: boolean;
  zTranslation: boolean;
}
export declare class TransformWidget extends ReglComponent {
  private cursor?;
  private xAxis?;
  private yAxis?;
  private zAxis?;
  private xArrow?;
  private yArrow?;
  private zArrow?;
  private xRotation?;
  private xyRotationLine?;
  private xzRotationLine?;
  private yRotation?;
  private yxRotationLine?;
  private yzRotationLine?;
  private zRotation?;
  private zxRotationLine?;
  private zyRotationLine?;
  private disabledAxis;
  private axisLines;
  private rotationLines;
  private translationMeshes;
  private rotationMeshes;
  private hoveredElement?;
  private transform?;
  private interactiveBounds?;
  private fullBounds?;
  private hoveredChanged;
  private xArrowFillColor?;
  private yArrowFillColor?;
  private zArrowFillColor?;
  private hoveredArrowFillColor?;
  private outlineColor?;
  constructor(canvasElement: HTMLCanvasElement, colors?: DrawableElementColors, initialDisabledAxes?: Partial<DisabledAxis>);
  dispose(): void;
  /**
   * @internal - visible for testing
   */
  getDrawableElements(): Drawable[];
  getFullBounds(): Rectangle.Rectangle | undefined;
  boundsContainsPoint(point: Point.Point): boolean;
  updateDisabledAxis(axis: Partial<DisabledAxis>): void;
  updateCursor(cursor?: Point.Point): void;
  updateTransform(transform?: Matrix4.Matrix4): void;
  updateColors(colors?: DrawableElementColors): void;
  onHoveredChanged(listener: Listener<Drawable | undefined>): Disposable;
  private updateDisabledOnDrawables;
  private updateHovered;
  private clearHovered;
  protected hasData(): boolean;
  protected createOrUpdateElements(): void;
  private createElements;
  private getXRotationColor;
  private getYRotationColor;
  private getZRotationColor;
  private getXTranslationColor;
  private getYTranslationColor;
  private getZTranslationColor;
  private createRotationLines;
  private updateElements;
}
