import { h } from '../../stencil-public-runtime';
import { FramePerspectiveCamera, Orientation } from '../../lib/types';
export declare class ViewerViewCube {
  private rendererEl?;
  private boxLength;
  private triadPosition;
  /**
   * The label for the side of the cube on the positive x-axis.
   */
  xPositiveLabel: string;
  /**
   * The label for the side of the cube on the negative x-axis.
   */
  xNegativeLabel: string;
  /**
   * The label for the side of the cube on the positive y-axis.
   */
  yPositiveLabel: string;
  /**
   * The label for the side of the cube on the negative y-axis.
   */
  yNegativeLabel: string;
  /**
   * The label for the side of the cube on the positive z-axis.
   */
  zPositiveLabel: string;
  /**
   * The label for the side of the cube on the negative z-axis.
   */
  zNegativeLabel: string;
  /**
   * Disables interactions for standard views.
   */
  standardViewsOff: boolean;
  /**
   * Whether to perform a `viewAll` when clicking on the view cube. If this
   * is set to `false`, the current `lookAt` point will be maintained, and the
   * camera's `position` and `up` vectors will be aligned to the standard view.
   * Defaults to `true`.
   *
   * **Note** Setting this value to `false` can result in the camera being placed
   * underneath geometry depending on the current `viewVector` length, resulting
   * in a view that may be unexpected.
   */
  viewAll: boolean;
  /**
   * The duration of the animation, in milliseconds, when a user performs a
   * standard view interaction. Set to 0 to disable animations.
   */
  animationDuration: number;
  /**
   * Disables the display of the triad.
   */
  triadOff: boolean;
  /**
   * @internal
   */
  worldOrientation: Orientation;
  /**
   * @internal
   */
  camera?: FramePerspectiveCamera;
  /**
   * The viewer element that is connected to the view cube.
   */
  viewer?: HTMLVertexViewerElement;
  protected handleViewerChanged(newViewer?: HTMLVertexViewerElement, oldViewer?: HTMLVertexViewerElement): void;
  private updateMatrices;
  private handleStandardView;
  /**
   * @ignore
   */
  protected componentWillLoad(): void;
  /**
   * @ignore
   */
  protected componentDidLoad(): void;
  private handleRendererResized;
  /**
   * @ignore
   */
  protected render(): h.JSX.IntrinsicElements;
}
