import { Matrix4, Vector3 } from '@vertexvis/geometry';
/**
 * Represents an orientation using an `up` and `forward` vector.
 */
export declare class Orientation {
  /**
   * The up orientation vector.
   */
  readonly y: Vector3.Vector3;
  /**
   * The forward orientation vector.
   */
  readonly z: Vector3.Vector3;
  /**
   * A default orientation where the up vector points up is represented as `[0, 1, 0]` and
   * forward is represented as `[0, 0, -1]`.
   */
  static DEFAULT: Orientation;
  constructor(
  /**
   * The up orientation vector.
   */
  y: Vector3.Vector3, 
  /**
   * The forward orientation vector.
   */
  z: Vector3.Vector3);
  /**
   * A rotation matrix for this orientation.
   */
  get matrix(): Matrix4.Matrix4;
}
