import { Matrix4, Vector3 } from '@vertexvis/geometry';
/**
 * A `StandardView` represents common view orientations for a camera.
 */
export declare class StandardView {
  /**
   * The position vector of the standard view.
   */
  readonly position: Vector3.Vector3;
  /**
   * The up vector of the standard view.
   */
  readonly up: Vector3.Vector3;
  /**
   * A standard view that positions the camera facing the front of the scene.
   */
  static FRONT: StandardView;
  /**
   * A standard view that positions the camera facing the left of the scene.
   */
  static RIGHT: StandardView;
  /**
   * A standard view that positions the camera facing the right of the scene.
   */
  static LEFT: StandardView;
  /**
   * A standard view that positions the camera facing the back of the scene.
   */
  static BACK: StandardView;
  /**
   * A standard view that positions the camera facing the top of the scene.
   */
  static TOP: StandardView;
  /**
   * A standard view that positions the camera facing the bottom of the scene.
   */
  static BOTTOM: StandardView;
  /**
   * A standard view that positions the camera facing the top-front-right of the
   * scene.
   */
  static TOP_FRONT_RIGHT: StandardView;
  /**
   * A standard view that positions the camera facing the top-front-left of the
   * scene.
   */
  static TOP_FRONT_LEFT: StandardView;
  /**
   * A standard view that positions the camera facing the bottom-front-right of
   * the scene.
   */
  static BOTTOM_FRONT_RIGHT: StandardView;
  /**
   * A standard view that positions the camera facing the bottom-front-left of
   * the scene.
   */
  static BOTTOM_FRONT_LEFT: StandardView;
  /**
   * A standard view that positions the camera facing the top-back-left of the
   * scene.
   */
  static TOP_BACK_LEFT: StandardView;
  /**
   * A standard view that positions the camera facing the top-back-right of the
   * scene.
   */
  static TOP_BACK_RIGHT: StandardView;
  /**
   * A standard view that positions the camera facing the bottom-back-left of
   * the scene.
   */
  static BOTTOM_BACK_LEFT: StandardView;
  /**
   * A standard view that positions the camera facing the bottom-back-right of
   * the scene.
   */
  static BOTTOM_BACK_RIGHT: StandardView;
  /**
   * A standard view that positions the camera facing the top-front of the
   * scene.
   */
  static TOP_FRONT: StandardView;
  /**
   * A standard view that positions the camera facing the bottom-front of the
   * scene.
   */
  static BOTTOM_FRONT: StandardView;
  /**
   * A standard view that positions the camera facing the front-right of the
   * scene.
   */
  static FRONT_RIGHT: StandardView;
  /**
   * A standard view that positions the camera facing the front-left of the
   * scene.
   */
  static FRONT_LEFT: StandardView;
  /**
   * A standard view that positions the camera facing the top-back of the scene.
   */
  static TOP_BACK: StandardView;
  /**
   * A standard view that positions the camera facing the bottom-back of the
   * scene.
   */
  static BOTTOM_BACK: StandardView;
  /**
   * A standard view that positions the camera facing the back-left of the
   * scene.
   */
  static BACK_LEFT: StandardView;
  /**
   * A standard view that positions the camera facing the back-right of the
   * scene.
   */
  static BACK_RIGHT: StandardView;
  /**
   * A standard view that positions the camera facing the top-left of the scene.
   */
  static TOP_LEFT: StandardView;
  /**
   * A standard view that positions the camera facing the top-right of the
   * scene.
   */
  static TOP_RIGHT: StandardView;
  /**
   * A standard view that positions the camera facing the bottom-left of the
   * scene.
   */
  static BOTTOM_LEFT: StandardView;
  /**
   * A standard view that positions the camera facing the bottom-right of the
   * scene.
   */
  static BOTTOM_RIGHT: StandardView;
  constructor(
  /**
   * The position vector of the standard view.
   */
  position: Vector3.Vector3, 
  /**
   * The up vector of the standard view.
   */
  up: Vector3.Vector3);
  /**
   * Returns a new standard view where the position and up vectors are
   * transformed with the given matrix.
   *
   * @param matrix A matrix.
   * @returns A new standard view.
   */
  transformMatrix(matrix: Matrix4.Matrix4): StandardView;
}
